/*!
 * Angular Material Design
 * https://github.com/angular/material
 * @license MIT
 * v0.11.1-master-83b01eb
 */
/*
*
*  Responsive attributes
*
*  References:
*  1) https://scotch.io/tutorials/a-visual-guide-to-css3-flexbox-properties#flex
*  2) https://css-tricks.com/almanac/properties/f/flex/
*  3) https://github.com/philipwalton/flexbugs#3-min-height-on-a-flex-container-wont-apply-to-its-flex-items
*  4) http://godban.com.ua/projects/flexgrid
*
*/
@-moz-document url-prefix() {
  .layout-fill {
    margin: 0;
    width: 100%;
    min-height: 100%;
    height: 100%; } }

/*
 *  Apply Mixins to create Layout/Flexbox styles
 *
 */
.layout {
  box-sizing: border-box;
  display: -webkit-flex;
  display: -moz-flex;
  display: -ms-flexbox;
  display: flex; }

.layout-column {
  -ms-flex-direction: column;
      flex-direction: column;
  -webkit-flex-direction: column; }

.layout-row {
  -ms-flex-direction: row;
      flex-direction: row;
  -webkit-flex-direction: row; }

.flex {
  box-sizing: border-box;
  -webkit-flex: 1;
      -ms-flex: 1;
          flex: 1; }

.flex-5, .md-css-only [flex="5"] {
  -webkit-flex: 0 0 5%;
      -ms-flex: 0 0 5%;
          flex: 0 0 5%; }

.layout--row > .flex-5, .md-css-only [layout="row"] > .md-css-only [flex="5"] {
  max-width: 5%;
  max-height: 100%; }

.layout--column > .flex-5, .md-css-only [layout="column"] > .md-css-only [flex="5"] {
  max-height: 5%;
  max-width: 100%; }

.flex-10, .md-css-only [flex="10"] {
  -webkit-flex: 0 0 10%;
      -ms-flex: 0 0 10%;
          flex: 0 0 10%; }

.layout--row > .flex-10, .md-css-only [layout="row"] > .md-css-only [flex="10"] {
  max-width: 10%;
  max-height: 100%; }

.layout--column > .flex-10, .md-css-only [layout="column"] > .md-css-only [flex="10"] {
  max-height: 10%;
  max-width: 100%; }

.flex-15, .md-css-only [flex="15"] {
  -webkit-flex: 0 0 15%;
      -ms-flex: 0 0 15%;
          flex: 0 0 15%; }

.layout--row > .flex-15, .md-css-only [layout="row"] > .md-css-only [flex="15"] {
  max-width: 15%;
  max-height: 100%; }

.layout--column > .flex-15, .md-css-only [layout="column"] > .md-css-only [flex="15"] {
  max-height: 15%;
  max-width: 100%; }

.flex-20, .md-css-only [flex="20"] {
  -webkit-flex: 0 0 20%;
      -ms-flex: 0 0 20%;
          flex: 0 0 20%; }

.layout--row > .flex-20, .md-css-only [layout="row"] > .md-css-only [flex="20"] {
  max-width: 20%;
  max-height: 100%; }

.layout--column > .flex-20, .md-css-only [layout="column"] > .md-css-only [flex="20"] {
  max-height: 20%;
  max-width: 100%; }

.flex-25, .md-css-only [flex="25"] {
  -webkit-flex: 0 0 25%;
      -ms-flex: 0 0 25%;
          flex: 0 0 25%; }

.layout--row > .flex-25, .md-css-only [layout="row"] > .md-css-only [flex="25"] {
  max-width: 25%;
  max-height: 100%; }

.layout--column > .flex-25, .md-css-only [layout="column"] > .md-css-only [flex="25"] {
  max-height: 25%;
  max-width: 100%; }

.flex-30, .md-css-only [flex="30"] {
  -webkit-flex: 0 0 30%;
      -ms-flex: 0 0 30%;
          flex: 0 0 30%; }

.layout--row > .flex-30, .md-css-only [layout="row"] > .md-css-only [flex="30"] {
  max-width: 30%;
  max-height: 100%; }

.layout--column > .flex-30, .md-css-only [layout="column"] > .md-css-only [flex="30"] {
  max-height: 30%;
  max-width: 100%; }

.flex-35, .md-css-only [flex="35"] {
  -webkit-flex: 0 0 35%;
      -ms-flex: 0 0 35%;
          flex: 0 0 35%; }

.layout--row > .flex-35, .md-css-only [layout="row"] > .md-css-only [flex="35"] {
  max-width: 35%;
  max-height: 100%; }

.layout--column > .flex-35, .md-css-only [layout="column"] > .md-css-only [flex="35"] {
  max-height: 35%;
  max-width: 100%; }

.flex-40, .md-css-only [flex="40"] {
  -webkit-flex: 0 0 40%;
      -ms-flex: 0 0 40%;
          flex: 0 0 40%; }

.layout--row > .flex-40, .md-css-only [layout="row"] > .md-css-only [flex="40"] {
  max-width: 40%;
  max-height: 100%; }

.layout--column > .flex-40, .md-css-only [layout="column"] > .md-css-only [flex="40"] {
  max-height: 40%;
  max-width: 100%; }

.flex-45, .md-css-only [flex="45"] {
  -webkit-flex: 0 0 45%;
      -ms-flex: 0 0 45%;
          flex: 0 0 45%; }

.layout--row > .flex-45, .md-css-only [layout="row"] > .md-css-only [flex="45"] {
  max-width: 45%;
  max-height: 100%; }

.layout--column > .flex-45, .md-css-only [layout="column"] > .md-css-only [flex="45"] {
  max-height: 45%;
  max-width: 100%; }

.flex-50, .md-css-only [flex="50"] {
  -webkit-flex: 0 0 50%;
      -ms-flex: 0 0 50%;
          flex: 0 0 50%; }

.layout--row > .flex-50, .md-css-only [layout="row"] > .md-css-only [flex="50"] {
  max-width: 50%;
  max-height: 100%; }

.layout--column > .flex-50, .md-css-only [layout="column"] > .md-css-only [flex="50"] {
  max-height: 50%;
  max-width: 100%; }

.flex-55, .md-css-only [flex="55"] {
  -webkit-flex: 0 0 55%;
      -ms-flex: 0 0 55%;
          flex: 0 0 55%; }

.layout--row > .flex-55, .md-css-only [layout="row"] > .md-css-only [flex="55"] {
  max-width: 55%;
  max-height: 100%; }

.layout--column > .flex-55, .md-css-only [layout="column"] > .md-css-only [flex="55"] {
  max-height: 55%;
  max-width: 100%; }

.flex-60, .md-css-only [flex="60"] {
  -webkit-flex: 0 0 60%;
      -ms-flex: 0 0 60%;
          flex: 0 0 60%; }

.layout--row > .flex-60, .md-css-only [layout="row"] > .md-css-only [flex="60"] {
  max-width: 60%;
  max-height: 100%; }

.layout--column > .flex-60, .md-css-only [layout="column"] > .md-css-only [flex="60"] {
  max-height: 60%;
  max-width: 100%; }

.flex-65, .md-css-only [flex="65"] {
  -webkit-flex: 0 0 65%;
      -ms-flex: 0 0 65%;
          flex: 0 0 65%; }

.layout--row > .flex-65, .md-css-only [layout="row"] > .md-css-only [flex="65"] {
  max-width: 65%;
  max-height: 100%; }

.layout--column > .flex-65, .md-css-only [layout="column"] > .md-css-only [flex="65"] {
  max-height: 65%;
  max-width: 100%; }

.flex-70, .md-css-only [flex="70"] {
  -webkit-flex: 0 0 70%;
      -ms-flex: 0 0 70%;
          flex: 0 0 70%; }

.layout--row > .flex-70, .md-css-only [layout="row"] > .md-css-only [flex="70"] {
  max-width: 70%;
  max-height: 100%; }

.layout--column > .flex-70, .md-css-only [layout="column"] > .md-css-only [flex="70"] {
  max-height: 70%;
  max-width: 100%; }

.flex-75, .md-css-only [flex="75"] {
  -webkit-flex: 0 0 75%;
      -ms-flex: 0 0 75%;
          flex: 0 0 75%; }

.layout--row > .flex-75, .md-css-only [layout="row"] > .md-css-only [flex="75"] {
  max-width: 75%;
  max-height: 100%; }

.layout--column > .flex-75, .md-css-only [layout="column"] > .md-css-only [flex="75"] {
  max-height: 75%;
  max-width: 100%; }

.flex-80, .md-css-only [flex="80"] {
  -webkit-flex: 0 0 80%;
      -ms-flex: 0 0 80%;
          flex: 0 0 80%; }

.layout--row > .flex-80, .md-css-only [layout="row"] > .md-css-only [flex="80"] {
  max-width: 80%;
  max-height: 100%; }

.layout--column > .flex-80, .md-css-only [layout="column"] > .md-css-only [flex="80"] {
  max-height: 80%;
  max-width: 100%; }

.flex-85, .md-css-only [flex="85"] {
  -webkit-flex: 0 0 85%;
      -ms-flex: 0 0 85%;
          flex: 0 0 85%; }

.layout--row > .flex-85, .md-css-only [layout="row"] > .md-css-only [flex="85"] {
  max-width: 85%;
  max-height: 100%; }

.layout--column > .flex-85, .md-css-only [layout="column"] > .md-css-only [flex="85"] {
  max-height: 85%;
  max-width: 100%; }

.flex-90, .md-css-only [flex="90"] {
  -webkit-flex: 0 0 90%;
      -ms-flex: 0 0 90%;
          flex: 0 0 90%; }

.layout--row > .flex-90, .md-css-only [layout="row"] > .md-css-only [flex="90"] {
  max-width: 90%;
  max-height: 100%; }

.layout--column > .flex-90, .md-css-only [layout="column"] > .md-css-only [flex="90"] {
  max-height: 90%;
  max-width: 100%; }

.flex-95, .md-css-only [flex="95"] {
  -webkit-flex: 0 0 95%;
      -ms-flex: 0 0 95%;
          flex: 0 0 95%; }

.layout--row > .flex-95, .md-css-only [layout="row"] > .md-css-only [flex="95"] {
  max-width: 95%;
  max-height: 100%; }

.layout--column > .flex-95, .md-css-only [layout="column"] > .md-css-only [flex="95"] {
  max-height: 95%;
  max-width: 100%; }

.flex-100, .md-css-only [flex="100"] {
  -webkit-flex: 0 0 100%;
      -ms-flex: 0 0 100%;
          flex: 0 0 100%; }

.layout--row > .flex-100, .md-css-only [layout="row"] > .md-css-only [flex="100"] {
  max-width: 100%;
  max-height: 100%; }

.layout--column > .flex-100, .md-css-only [layout="column"] > .md-css-only [flex="100"] {
  max-height: 100%;
  max-width: 100%; }

.flex-33, .flex-34 {
  -webkit-flex: 0 0 33%;
      -ms-flex: 0 0 33%;
          flex: 0 0 33%;
  max-width: 33%;
  max-height: 100%; }

.flex-66, .flex-67 {
  -webkit-flex: 0 0 67%;
      -ms-flex: 0 0 67%;
          flex: 0 0 67%;
  max-width: 67%;
  max-height: 100%; }

.layout--row > .flex-33, .layout--row > .flex-34 {
  max-width: 33%;
  max-height: 100%; }
.layout--row > .flex-66, .layout--row > .flex-67 {
  max-width: 67%;
  max-height: 100%; }

.layout--column > .flex-33, .layout--column > .flex-34 {
  max-height: 33%;
  max-width: 100%; }
.layout--column > .flex-66, .layout--column > .flex-67 {
  max-height: 67%;
  max-width: 100%; }

.layout-align-center, .layout-align-center-center, .layout-align-center-start, .layout-align-center-end, .md-css-only [layout-align="center"], .md-css-only [layout-align="center center"], .md-css-only [layout-align="center start"], .md-css-only [layout-align="center end"] {
  -webkit-justify-content: center;
      -ms-flex-pack: center;
          justify-content: center; }

.layout-align-end, .layout-align-end-center, .layout-align-end-start, .layout-align-end-end, .md-css-only [layout-align="end"], .md-css-only [layout-align="end center"], .md-css-only [layout-align="end start"], .md-css-only [layout-align="end end"] {
  -webkit-justify-content: flex-end;
      -ms-flex-pack: end;
          justify-content: flex-end; }

.layout-align-space-around, .layout-align-space-around-center, .layout-align-space-around-start, .layout-align-space-around-end, .md-css-only [layout-align="space-around"], .md-css-only [layout-align="space-around center"], .md-css-only [layout-align="space-around start"], .md-css-only [layout-align="space-around end"] {
  -webkit-justify-content: space-around;
      -ms-flex-pack: distribute;
          justify-content: space-around; }

.layout-align-space-between, .layout-align-space-between-center, .layout-align-space-between-start, .layout-align-space-between-end, .md-css-only [layout-align="space-between"], .md-css-only [layout-align="space-between center"], .md-css-only [layout-align="space-between start"], .md-css-only [layout-align="space-between end"] {
  -webkit-justify-content: space-between;
      -ms-flex-pack: justify;
          justify-content: space-between; }

.layout-align-center-start, .layout-align-start-start, .layout-align-end-start, .layout-align-space-between-start, .layout-align-space-around-start, .md-css-only [layout-align="center start"], .md-css-only [layout-align="start start"], .md-css-only [layout-align="end start"], .md-css-only [layout-align="space-between start"], .md-css-only [layout-align="space-around start"] {
  -webkit-align-items: flex-start;
      -ms-flex-align: start;
          align-items: flex-start; }

.layout-align-center-center, .layout-align-start-center, .layout-align-end-center, .layout-align-space-between-center, .layout-align-space-around-center, .md-css-only [layout-align="center center"], .md-css-only [layout-align="start center"], .md-css-only [layout-align="end center"], .md-css-only [layout-align="space-between center"], .md-css-only [layout-align="space-around center"] {
  -webkit-align-items: center;
      -ms-flex-align: center;
          align-items: center;
  max-width: 100%; }

.layout-align-center-end, .layout-align-start-end, .layout-align-end-end, .layout-align-space-between-end, .layout-align-space-around-end, .md-css-only [layout-align="center end"], .md-css-only [layout-align="start end"], .md-css-only [layout-align="end end"], .md-css-only [layout-align="space-between end"], .md-css-only [layout-align="space-around end"] {
  -webkit-align-items: flex-end;
      -ms-flex-align: end;
          align-items: flex-end; }

.flex-order, .flex-order--9, .flex-order-sm--9, .flex-order-gt-sm--9, .flex-order-md--9, .flex-order-gt-md--9, .flex-order-lg--9, .flex-order-gt-lg--9 {
  -webkit-order: -9;
      -ms-flex-order: -9;
          order: -9; }

.flex-order--8, .flex-order-sm--8, .flex-order-gt-sm--8, .flex-order-md--8, .flex-order-gt-md--8, .flex-order-lg--8, .flex-order-gt-lg--8 {
  -webkit-order: -8;
      -ms-flex-order: -8;
          order: -8; }

.flex-order--7, .flex-order-sm--7, .flex-order-gt-sm--7, .flex-order-md--7, .flex-order-gt-md--7, .flex-order-lg--7, .flex-order-gt-lg--7 {
  -webkit-order: -7;
      -ms-flex-order: -7;
          order: -7; }

.flex-order--6, .flex-order-sm--6, .flex-order-gt-sm--6, .flex-order-md--6, .flex-order-gt-md--6, .flex-order-lg--6, .flex-order-gt-lg--6 {
  -webkit-order: -6;
      -ms-flex-order: -6;
          order: -6; }

.flex-order--5, .flex-order-sm--5, .flex-order-gt-sm--5, .flex-order-md--5, .flex-order-gt-md--5, .flex-order-lg--5, .flex-order-gt-lg--5 {
  -webkit-order: -5;
      -ms-flex-order: -5;
          order: -5; }

.flex-order--4, .flex-order-sm--4, .flex-order-gt-sm--4, .flex-order-md--4, .flex-order-gt-md--4, .flex-order-lg--4, .flex-order-gt-lg--4 {
  -webkit-order: -4;
      -ms-flex-order: -4;
          order: -4; }

.flex-order--3, .flex-order-sm--3, .flex-order-gt-sm--3, .flex-order-md--3, .flex-order-gt-md--3, .flex-order-lg--3, .flex-order-gt-lg--3 {
  -webkit-order: -3;
      -ms-flex-order: -3;
          order: -3; }

.flex-order--2, .flex-order-sm--2, .flex-order-gt-sm--2, .flex-order-md--2, .flex-order-gt-md--2, .flex-order-lg--2, .flex-order-gt-lg--2 {
  -webkit-order: -2;
      -ms-flex-order: -2;
          order: -2; }

.flex-order--1, .flex-order-sm--1, .flex-order-gt-sm--1, .flex-order-md--1, .flex-order-gt-md--1, .flex-order-lg--1, .flex-order-gt-lg--1 {
  -webkit-order: -1;
      -ms-flex-order: -1;
          order: -1; }

.flex-order-0, .flex-order-sm-0, .flex-order-gt-sm-0, .flex-order-md-0, .flex-order-gt-md-0, .flex-order-lg-0, .flex-order-gt-lg-0 {
  -webkit-order: 0;
      -ms-flex-order: 0;
          order: 0; }

.flex-order-1, .flex-order-sm-1, .flex-order-gt-sm-1, .flex-order-md-1, .flex-order-gt-md-1, .flex-order-lg-1, .flex-order-gt-lg-1 {
  -webkit-order: 1;
      -ms-flex-order: 1;
          order: 1; }

.flex-order-2, .flex-order-sm-2, .flex-order-gt-sm-2, .flex-order-md-2, .flex-order-gt-md-2, .flex-order-lg-2, .flex-order-gt-lg-2 {
  -webkit-order: 2;
      -ms-flex-order: 2;
          order: 2; }

.flex-order-3, .flex-order-sm-3, .flex-order-gt-sm-3, .flex-order-md-3, .flex-order-gt-md-3, .flex-order-lg-3, .flex-order-gt-lg-3 {
  -webkit-order: 3;
      -ms-flex-order: 3;
          order: 3; }

.flex-order-4, .flex-order-sm-4, .flex-order-gt-sm-4, .flex-order-md-4, .flex-order-gt-md-4, .flex-order-lg-4, .flex-order-gt-lg-4 {
  -webkit-order: 4;
      -ms-flex-order: 4;
          order: 4; }

.flex-order-5, .flex-order-sm-5, .flex-order-gt-sm-5, .flex-order-md-5, .flex-order-gt-md-5, .flex-order-lg-5, .flex-order-gt-lg-5 {
  -webkit-order: 5;
      -ms-flex-order: 5;
          order: 5; }

.flex-order-6, .flex-order-sm-6, .flex-order-gt-sm-6, .flex-order-md-6, .flex-order-gt-md-6, .flex-order-lg-6, .flex-order-gt-lg-6 {
  -webkit-order: 6;
      -ms-flex-order: 6;
          order: 6; }

.flex-order-7, .flex-order-sm-7, .flex-order-gt-sm-7, .flex-order-md-7, .flex-order-gt-md-7, .flex-order-lg-7, .flex-order-gt-lg-7 {
  -webkit-order: 7;
      -ms-flex-order: 7;
          order: 7; }

.flex-order-8, .flex-order-sm-8, .flex-order-gt-sm-8, .flex-order-md-8, .flex-order-gt-md-8, .flex-order-lg-8, .flex-order-gt-lg-8 {
  -webkit-order: 8;
      -ms-flex-order: 8;
          order: 8; }

.flex-order-9, .flex-order-sm-9, .flex-order-gt-sm-9, .flex-order-md-9, .flex-order-gt-md-9, .flex-order-lg-9, .flex-order-gt-lg-9 {
  -webkit-order: 9;
      -ms-flex-order: 9;
          order: 9; }

.offset-5, .md-css-only [offset="5"] {
  margin-left: 5%; }

.offset-10, .md-css-only [offset="10"] {
  margin-left: 10%; }

.offset-15, .md-css-only [offset="15"] {
  margin-left: 15%; }

.offset-20, .md-css-only [offset="20"] {
  margin-left: 20%; }

.offset-25, .md-css-only [offset="25"] {
  margin-left: 25%; }

.offset-30, .md-css-only [offset="30"] {
  margin-left: 30%; }

.offset-35, .md-css-only [offset="35"] {
  margin-left: 35%; }

.offset-40, .md-css-only [offset="40"] {
  margin-left: 40%; }

.offset-45, .md-css-only [offset="45"] {
  margin-left: 45%; }

.offset-50, .md-css-only [offset="50"] {
  margin-left: 50%; }

.offset-55, .md-css-only [offset="55"] {
  margin-left: 55%; }

.offset-60, .md-css-only [offset="60"] {
  margin-left: 60%; }

.offset-65, .md-css-only [offset="65"] {
  margin-left: 65%; }

.offset-70, .md-css-only [offset="70"] {
  margin-left: 70%; }

.offset-75, .md-css-only [offset="75"] {
  margin-left: 75%; }

.offset-80, .md-css-only [offset="80"] {
  margin-left: 80%; }

.offset-85, .md-css-only [offset="85"] {
  margin-left: 85%; }

.offset-90, .md-css-only [offset="90"] {
  margin-left: 90%; }

.offset-95, .md-css-only [offset="95"] {
  margin-left: 95%; }

.offset-33, .offset-34 {
  margin-left: 34%; }

.offset-66, .offset-67 {
  margin-left: 66%; }

.layout-padding > .flex-sm, .layout-padding > .flex-lt-md, .md-css-only [layout-padding] > [flex-sm], .md-css-only [layout-padding] > [flex-lt-md] {
  padding: 4px; }

.layout-padding, .layout-padding > .flex, .layout-padding > .flex-gt-sm, .layout-padding > .flex-md, .layout-padding > .flex-lt-lg, .md-css-only [layout-padding], .md-css-only [layout-padding] > .md-css-only [flex], .md-css-only [layout-padding] > .md-css-only [flex-gt-sm], .md-css-only [layout-padding] > .md-css-only [flex-md], .md-css-only [layout-padding] > .md-css-only [flex-lt-lg] {
  padding: 8px; }

.layout-padding > .flex-gt-md, .layout-padding > .flex-lg, .md-css-only [layout-padding] > .md-css-only [flex-gt-md], .md-css-only [layout-padding] > .md-css-only [flex-lg] {
  padding: 16px; }

.layout-margin > .flex-sm, .layout-margin > .flex-lt-md, .md-css-only [layout-margin] > .md-css-only [flex-sm], .md-css-only [layout-margin] > .md-css-only [flex-lt-md] {
  margin: 4px; }

.layout-margin, .layout-margin > .flex, .layout-margin > .flex-gt-sm, .layout-margin > .flex-md, .layout-margin > .flex-lt-lg, .md-css-only [layout-margin], .md-css-only [layout-margin] > .md-css-only [flex], .md-css-only [layout-margin] > .md-css-only [flex-gt-sm], .md-css-only [layout-margin] > .md-css-only [flex-md], .md-css-only [layout-margin] > .md-css-only [flex-lt-lg] {
  margin: 8px; }

.layout-margin > .flex-gt-md, .layout-margin > .flex-lg, .md-css-only [layout-margin] > .md-css-only [flex-gt-md], .md-css-only [layout-margin] > .md-css-only [flex-lg] {
  margin: 16px; }

.layout-wrap {
  -webkit-flex-wrap: wrap;
      -ms-flex-wrap: wrap;
          flex-wrap: wrap; }

.layout-fill {
  margin: 0;
  width: 100%;
  min-height: 100%;
  height: 100%; }

/**
 * `hide-gt-sm show-gt-lg` should hide from 600px to 1200px
 * `show-md hide-gt-sm` should show from 0px to 960px and hide at >960px
 * `hide-gt-md show-gt-sm` should show everywhere (show overrides hide)`
 *
 *  hide means hide everywhere
 *  Sizes:
 *         0    <= size < 600  Phone
 *         600  <= size < 960  Tablet
 *         960  <= size < 1200 Tablet-Landscape
 */
@media (max-width: 599px) {
  .hide-sm:not(.show-sm):not(.show), .hide:not(.show-sm):not(.show) {
    display: none; }
  .layout-sm {
    box-sizing: border-box;
    display: -webkit-flex;
    display: -ms-flexbox;
    display: flex; }
  .layout-sm-column, .md-css-only [layout-sm=column] {
    -webkit-flex-direction: column;
        -ms-flex-direction: column;
            flex-direction: column; }
  .layout-sm-row, .md-css-only [layout-sm=row] {
    -webkit-flex-direction: row;
        -ms-flex-direction: row;
            flex-direction: row;
    -webkit-flex-wrap: wrap;
        -ms-flex-wrap: wrap;
            flex-wrap: wrap; }
  .flex-sm {
    box-sizing: border-box;
    -webkit-flex: 1;
        -ms-flex: 1;
            flex: 1; }
  .flex-sm-5, .md-css-only [flex-sm="5"] {
    -webkit-flex: 0 0 5%;
        -ms-flex: 0 0 5%;
            flex: 0 0 5%; }
  .layout-sm-row > .flex-sm-5, .md-css-only [layout="row"] > .md-css-only [flex-sm="5"] {
    max-width: 5%;
    max-height: 100%; }
  .layout-sm-column > .flex-sm-5, .md-css-only [layout="column"] > .md-css-only [flex-sm="5"] {
    max-height: 5%;
    max-width: 100%; }
  .flex-sm-10, .md-css-only [flex-sm="10"] {
    -webkit-flex: 0 0 10%;
        -ms-flex: 0 0 10%;
            flex: 0 0 10%; }
  .layout-sm-row > .flex-sm-10, .md-css-only [layout="row"] > .md-css-only [flex-sm="10"] {
    max-width: 10%;
    max-height: 100%; }
  .layout-sm-column > .flex-sm-10, .md-css-only [layout="column"] > .md-css-only [flex-sm="10"] {
    max-height: 10%;
    max-width: 100%; }
  .flex-sm-15, .md-css-only [flex-sm="15"] {
    -webkit-flex: 0 0 15%;
        -ms-flex: 0 0 15%;
            flex: 0 0 15%; }
  .layout-sm-row > .flex-sm-15, .md-css-only [layout="row"] > .md-css-only [flex-sm="15"] {
    max-width: 15%;
    max-height: 100%; }
  .layout-sm-column > .flex-sm-15, .md-css-only [layout="column"] > .md-css-only [flex-sm="15"] {
    max-height: 15%;
    max-width: 100%; }
  .flex-sm-20, .md-css-only [flex-sm="20"] {
    -webkit-flex: 0 0 20%;
        -ms-flex: 0 0 20%;
            flex: 0 0 20%; }
  .layout-sm-row > .flex-sm-20, .md-css-only [layout="row"] > .md-css-only [flex-sm="20"] {
    max-width: 20%;
    max-height: 100%; }
  .layout-sm-column > .flex-sm-20, .md-css-only [layout="column"] > .md-css-only [flex-sm="20"] {
    max-height: 20%;
    max-width: 100%; }
  .flex-sm-25, .md-css-only [flex-sm="25"] {
    -webkit-flex: 0 0 25%;
        -ms-flex: 0 0 25%;
            flex: 0 0 25%; }
  .layout-sm-row > .flex-sm-25, .md-css-only [layout="row"] > .md-css-only [flex-sm="25"] {
    max-width: 25%;
    max-height: 100%; }
  .layout-sm-column > .flex-sm-25, .md-css-only [layout="column"] > .md-css-only [flex-sm="25"] {
    max-height: 25%;
    max-width: 100%; }
  .flex-sm-30, .md-css-only [flex-sm="30"] {
    -webkit-flex: 0 0 30%;
        -ms-flex: 0 0 30%;
            flex: 0 0 30%; }
  .layout-sm-row > .flex-sm-30, .md-css-only [layout="row"] > .md-css-only [flex-sm="30"] {
    max-width: 30%;
    max-height: 100%; }
  .layout-sm-column > .flex-sm-30, .md-css-only [layout="column"] > .md-css-only [flex-sm="30"] {
    max-height: 30%;
    max-width: 100%; }
  .flex-sm-35, .md-css-only [flex-sm="35"] {
    -webkit-flex: 0 0 35%;
        -ms-flex: 0 0 35%;
            flex: 0 0 35%; }
  .layout-sm-row > .flex-sm-35, .md-css-only [layout="row"] > .md-css-only [flex-sm="35"] {
    max-width: 35%;
    max-height: 100%; }
  .layout-sm-column > .flex-sm-35, .md-css-only [layout="column"] > .md-css-only [flex-sm="35"] {
    max-height: 35%;
    max-width: 100%; }
  .flex-sm-40, .md-css-only [flex-sm="40"] {
    -webkit-flex: 0 0 40%;
        -ms-flex: 0 0 40%;
            flex: 0 0 40%; }
  .layout-sm-row > .flex-sm-40, .md-css-only [layout="row"] > .md-css-only [flex-sm="40"] {
    max-width: 40%;
    max-height: 100%; }
  .layout-sm-column > .flex-sm-40, .md-css-only [layout="column"] > .md-css-only [flex-sm="40"] {
    max-height: 40%;
    max-width: 100%; }
  .flex-sm-45, .md-css-only [flex-sm="45"] {
    -webkit-flex: 0 0 45%;
        -ms-flex: 0 0 45%;
            flex: 0 0 45%; }
  .layout-sm-row > .flex-sm-45, .md-css-only [layout="row"] > .md-css-only [flex-sm="45"] {
    max-width: 45%;
    max-height: 100%; }
  .layout-sm-column > .flex-sm-45, .md-css-only [layout="column"] > .md-css-only [flex-sm="45"] {
    max-height: 45%;
    max-width: 100%; }
  .flex-sm-50, .md-css-only [flex-sm="50"] {
    -webkit-flex: 0 0 50%;
        -ms-flex: 0 0 50%;
            flex: 0 0 50%; }
  .layout-sm-row > .flex-sm-50, .md-css-only [layout="row"] > .md-css-only [flex-sm="50"] {
    max-width: 50%;
    max-height: 100%; }
  .layout-sm-column > .flex-sm-50, .md-css-only [layout="column"] > .md-css-only [flex-sm="50"] {
    max-height: 50%;
    max-width: 100%; }
  .flex-sm-55, .md-css-only [flex-sm="55"] {
    -webkit-flex: 0 0 55%;
        -ms-flex: 0 0 55%;
            flex: 0 0 55%; }
  .layout-sm-row > .flex-sm-55, .md-css-only [layout="row"] > .md-css-only [flex-sm="55"] {
    max-width: 55%;
    max-height: 100%; }
  .layout-sm-column > .flex-sm-55, .md-css-only [layout="column"] > .md-css-only [flex-sm="55"] {
    max-height: 55%;
    max-width: 100%; }
  .flex-sm-60, .md-css-only [flex-sm="60"] {
    -webkit-flex: 0 0 60%;
        -ms-flex: 0 0 60%;
            flex: 0 0 60%; }
  .layout-sm-row > .flex-sm-60, .md-css-only [layout="row"] > .md-css-only [flex-sm="60"] {
    max-width: 60%;
    max-height: 100%; }
  .layout-sm-column > .flex-sm-60, .md-css-only [layout="column"] > .md-css-only [flex-sm="60"] {
    max-height: 60%;
    max-width: 100%; }
  .flex-sm-65, .md-css-only [flex-sm="65"] {
    -webkit-flex: 0 0 65%;
        -ms-flex: 0 0 65%;
            flex: 0 0 65%; }
  .layout-sm-row > .flex-sm-65, .md-css-only [layout="row"] > .md-css-only [flex-sm="65"] {
    max-width: 65%;
    max-height: 100%; }
  .layout-sm-column > .flex-sm-65, .md-css-only [layout="column"] > .md-css-only [flex-sm="65"] {
    max-height: 65%;
    max-width: 100%; }
  .flex-sm-70, .md-css-only [flex-sm="70"] {
    -webkit-flex: 0 0 70%;
        -ms-flex: 0 0 70%;
            flex: 0 0 70%; }
  .layout-sm-row > .flex-sm-70, .md-css-only [layout="row"] > .md-css-only [flex-sm="70"] {
    max-width: 70%;
    max-height: 100%; }
  .layout-sm-column > .flex-sm-70, .md-css-only [layout="column"] > .md-css-only [flex-sm="70"] {
    max-height: 70%;
    max-width: 100%; }
  .flex-sm-75, .md-css-only [flex-sm="75"] {
    -webkit-flex: 0 0 75%;
        -ms-flex: 0 0 75%;
            flex: 0 0 75%; }
  .layout-sm-row > .flex-sm-75, .md-css-only [layout="row"] > .md-css-only [flex-sm="75"] {
    max-width: 75%;
    max-height: 100%; }
  .layout-sm-column > .flex-sm-75, .md-css-only [layout="column"] > .md-css-only [flex-sm="75"] {
    max-height: 75%;
    max-width: 100%; }
  .flex-sm-80, .md-css-only [flex-sm="80"] {
    -webkit-flex: 0 0 80%;
        -ms-flex: 0 0 80%;
            flex: 0 0 80%; }
  .layout-sm-row > .flex-sm-80, .md-css-only [layout="row"] > .md-css-only [flex-sm="80"] {
    max-width: 80%;
    max-height: 100%; }
  .layout-sm-column > .flex-sm-80, .md-css-only [layout="column"] > .md-css-only [flex-sm="80"] {
    max-height: 80%;
    max-width: 100%; }
  .flex-sm-85, .md-css-only [flex-sm="85"] {
    -webkit-flex: 0 0 85%;
        -ms-flex: 0 0 85%;
            flex: 0 0 85%; }
  .layout-sm-row > .flex-sm-85, .md-css-only [layout="row"] > .md-css-only [flex-sm="85"] {
    max-width: 85%;
    max-height: 100%; }
  .layout-sm-column > .flex-sm-85, .md-css-only [layout="column"] > .md-css-only [flex-sm="85"] {
    max-height: 85%;
    max-width: 100%; }
  .flex-sm-90, .md-css-only [flex-sm="90"] {
    -webkit-flex: 0 0 90%;
        -ms-flex: 0 0 90%;
            flex: 0 0 90%; }
  .layout-sm-row > .flex-sm-90, .md-css-only [layout="row"] > .md-css-only [flex-sm="90"] {
    max-width: 90%;
    max-height: 100%; }
  .layout-sm-column > .flex-sm-90, .md-css-only [layout="column"] > .md-css-only [flex-sm="90"] {
    max-height: 90%;
    max-width: 100%; }
  .flex-sm-95, .md-css-only [flex-sm="95"] {
    -webkit-flex: 0 0 95%;
        -ms-flex: 0 0 95%;
            flex: 0 0 95%; }
  .layout-sm-row > .flex-sm-95, .md-css-only [layout="row"] > .md-css-only [flex-sm="95"] {
    max-width: 95%;
    max-height: 100%; }
  .layout-sm-column > .flex-sm-95, .md-css-only [layout="column"] > .md-css-only [flex-sm="95"] {
    max-height: 95%;
    max-width: 100%; }
  .flex-sm-100, .md-css-only [flex-sm="100"] {
    -webkit-flex: 0 0 100%;
        -ms-flex: 0 0 100%;
            flex: 0 0 100%; }
  .layout-sm-row > .flex-sm-100, .md-css-only [layout="row"] > .md-css-only [flex-sm="100"] {
    max-width: 100%;
    max-height: 100%; }
  .layout-sm-column > .flex-sm-100, .md-css-only [layout="column"] > .md-css-only [flex-sm="100"] {
    max-height: 100%;
    max-width: 100%; }
  .flex-sm-33, .flex-sm-34 {
    -webkit-flex: 0 0 33%;
        -ms-flex: 0 0 33%;
            flex: 0 0 33%;
    max-width: 33%;
    max-height: 100%; }
  .flex-sm-66, .flex-sm-67 {
    -webkit-flex: 0 0 67%;
        -ms-flex: 0 0 67%;
            flex: 0 0 67%;
    max-width: 67%;
    max-height: 100%; }
  .layout-sm-row > .flex-sm-33, .layout-sm-row > .flex-sm-34 {
    max-width: 33%;
    max-height: 100%; }
  .layout-sm-row > .flex-sm-66, .layout-sm-row > .flex-sm-67 {
    max-width: 67%;
    max-height: 100%; }
  .layout-sm-column > .flex-sm-33, .layout-sm-column > .flex-sm-34 {
    max-height: 33%;
    max-width: 100%; }
  .layout-sm-column > .flex-sm-66, .layout-sm-column > .flex-sm-67 {
    max-height: 67%;
    max-width: 100%; } }

@media (min-width: 600px) {
  .layout-gt-sm {
    box-sizing: border-box;
    display: -webkit-flex;
    display: -ms-flexbox;
    display: flex; }
  .layout-gt-sm-column, .md-css-only [layout-gt-sm=column] {
    -webkit-flex-direction: column;
        -ms-flex-direction: column;
            flex-direction: column; }
  .layout-gt-sm-row, .md-css-only [layout-gt-sm=row] {
    -webkit-flex-direction: row;
        -ms-flex-direction: row;
            flex-direction: row;
    -webkit-flex-wrap: wrap;
        -ms-flex-wrap: wrap;
            flex-wrap: wrap; }
  .flex-gt-sm {
    box-sizing: border-box;
    -webkit-flex: 1;
        -ms-flex: 1;
            flex: 1; }
  .flex-gt-sm-5, .md-css-only [flex-gt-sm="5"] {
    -webkit-flex: 0 0 5%;
        -ms-flex: 0 0 5%;
            flex: 0 0 5%; }
  .layout-gt-sm-row > .flex-gt-sm-5, .md-css-only [layout="row"] > .md-css-only [flex-gt-sm="5"] {
    max-width: 5%;
    max-height: 100%; }
  .layout-gt-sm-column > .flex-gt-sm-5, .md-css-only [layout="column"] > .md-css-only [flex-gt-sm="5"] {
    max-height: 5%;
    max-width: 100%; }
  .flex-gt-sm-10, .md-css-only [flex-gt-sm="10"] {
    -webkit-flex: 0 0 10%;
        -ms-flex: 0 0 10%;
            flex: 0 0 10%; }
  .layout-gt-sm-row > .flex-gt-sm-10, .md-css-only [layout="row"] > .md-css-only [flex-gt-sm="10"] {
    max-width: 10%;
    max-height: 100%; }
  .layout-gt-sm-column > .flex-gt-sm-10, .md-css-only [layout="column"] > .md-css-only [flex-gt-sm="10"] {
    max-height: 10%;
    max-width: 100%; }
  .flex-gt-sm-15, .md-css-only [flex-gt-sm="15"] {
    -webkit-flex: 0 0 15%;
        -ms-flex: 0 0 15%;
            flex: 0 0 15%; }
  .layout-gt-sm-row > .flex-gt-sm-15, .md-css-only [layout="row"] > .md-css-only [flex-gt-sm="15"] {
    max-width: 15%;
    max-height: 100%; }
  .layout-gt-sm-column > .flex-gt-sm-15, .md-css-only [layout="column"] > .md-css-only [flex-gt-sm="15"] {
    max-height: 15%;
    max-width: 100%; }
  .flex-gt-sm-20, .md-css-only [flex-gt-sm="20"] {
    -webkit-flex: 0 0 20%;
        -ms-flex: 0 0 20%;
            flex: 0 0 20%; }
  .layout-gt-sm-row > .flex-gt-sm-20, .md-css-only [layout="row"] > .md-css-only [flex-gt-sm="20"] {
    max-width: 20%;
    max-height: 100%; }
  .layout-gt-sm-column > .flex-gt-sm-20, .md-css-only [layout="column"] > .md-css-only [flex-gt-sm="20"] {
    max-height: 20%;
    max-width: 100%; }
  .flex-gt-sm-25, .md-css-only [flex-gt-sm="25"] {
    -webkit-flex: 0 0 25%;
        -ms-flex: 0 0 25%;
            flex: 0 0 25%; }
  .layout-gt-sm-row > .flex-gt-sm-25, .md-css-only [layout="row"] > .md-css-only [flex-gt-sm="25"] {
    max-width: 25%;
    max-height: 100%; }
  .layout-gt-sm-column > .flex-gt-sm-25, .md-css-only [layout="column"] > .md-css-only [flex-gt-sm="25"] {
    max-height: 25%;
    max-width: 100%; }
  .flex-gt-sm-30, .md-css-only [flex-gt-sm="30"] {
    -webkit-flex: 0 0 30%;
        -ms-flex: 0 0 30%;
            flex: 0 0 30%; }
  .layout-gt-sm-row > .flex-gt-sm-30, .md-css-only [layout="row"] > .md-css-only [flex-gt-sm="30"] {
    max-width: 30%;
    max-height: 100%; }
  .layout-gt-sm-column > .flex-gt-sm-30, .md-css-only [layout="column"] > .md-css-only [flex-gt-sm="30"] {
    max-height: 30%;
    max-width: 100%; }
  .flex-gt-sm-35, .md-css-only [flex-gt-sm="35"] {
    -webkit-flex: 0 0 35%;
        -ms-flex: 0 0 35%;
            flex: 0 0 35%; }
  .layout-gt-sm-row > .flex-gt-sm-35, .md-css-only [layout="row"] > .md-css-only [flex-gt-sm="35"] {
    max-width: 35%;
    max-height: 100%; }
  .layout-gt-sm-column > .flex-gt-sm-35, .md-css-only [layout="column"] > .md-css-only [flex-gt-sm="35"] {
    max-height: 35%;
    max-width: 100%; }
  .flex-gt-sm-40, .md-css-only [flex-gt-sm="40"] {
    -webkit-flex: 0 0 40%;
        -ms-flex: 0 0 40%;
            flex: 0 0 40%; }
  .layout-gt-sm-row > .flex-gt-sm-40, .md-css-only [layout="row"] > .md-css-only [flex-gt-sm="40"] {
    max-width: 40%;
    max-height: 100%; }
  .layout-gt-sm-column > .flex-gt-sm-40, .md-css-only [layout="column"] > .md-css-only [flex-gt-sm="40"] {
    max-height: 40%;
    max-width: 100%; }
  .flex-gt-sm-45, .md-css-only [flex-gt-sm="45"] {
    -webkit-flex: 0 0 45%;
        -ms-flex: 0 0 45%;
            flex: 0 0 45%; }
  .layout-gt-sm-row > .flex-gt-sm-45, .md-css-only [layout="row"] > .md-css-only [flex-gt-sm="45"] {
    max-width: 45%;
    max-height: 100%; }
  .layout-gt-sm-column > .flex-gt-sm-45, .md-css-only [layout="column"] > .md-css-only [flex-gt-sm="45"] {
    max-height: 45%;
    max-width: 100%; }
  .flex-gt-sm-50, .md-css-only [flex-gt-sm="50"] {
    -webkit-flex: 0 0 50%;
        -ms-flex: 0 0 50%;
            flex: 0 0 50%; }
  .layout-gt-sm-row > .flex-gt-sm-50, .md-css-only [layout="row"] > .md-css-only [flex-gt-sm="50"] {
    max-width: 50%;
    max-height: 100%; }
  .layout-gt-sm-column > .flex-gt-sm-50, .md-css-only [layout="column"] > .md-css-only [flex-gt-sm="50"] {
    max-height: 50%;
    max-width: 100%; }
  .flex-gt-sm-55, .md-css-only [flex-gt-sm="55"] {
    -webkit-flex: 0 0 55%;
        -ms-flex: 0 0 55%;
            flex: 0 0 55%; }
  .layout-gt-sm-row > .flex-gt-sm-55, .md-css-only [layout="row"] > .md-css-only [flex-gt-sm="55"] {
    max-width: 55%;
    max-height: 100%; }
  .layout-gt-sm-column > .flex-gt-sm-55, .md-css-only [layout="column"] > .md-css-only [flex-gt-sm="55"] {
    max-height: 55%;
    max-width: 100%; }
  .flex-gt-sm-60, .md-css-only [flex-gt-sm="60"] {
    -webkit-flex: 0 0 60%;
        -ms-flex: 0 0 60%;
            flex: 0 0 60%; }
  .layout-gt-sm-row > .flex-gt-sm-60, .md-css-only [layout="row"] > .md-css-only [flex-gt-sm="60"] {
    max-width: 60%;
    max-height: 100%; }
  .layout-gt-sm-column > .flex-gt-sm-60, .md-css-only [layout="column"] > .md-css-only [flex-gt-sm="60"] {
    max-height: 60%;
    max-width: 100%; }
  .flex-gt-sm-65, .md-css-only [flex-gt-sm="65"] {
    -webkit-flex: 0 0 65%;
        -ms-flex: 0 0 65%;
            flex: 0 0 65%; }
  .layout-gt-sm-row > .flex-gt-sm-65, .md-css-only [layout="row"] > .md-css-only [flex-gt-sm="65"] {
    max-width: 65%;
    max-height: 100%; }
  .layout-gt-sm-column > .flex-gt-sm-65, .md-css-only [layout="column"] > .md-css-only [flex-gt-sm="65"] {
    max-height: 65%;
    max-width: 100%; }
  .flex-gt-sm-70, .md-css-only [flex-gt-sm="70"] {
    -webkit-flex: 0 0 70%;
        -ms-flex: 0 0 70%;
            flex: 0 0 70%; }
  .layout-gt-sm-row > .flex-gt-sm-70, .md-css-only [layout="row"] > .md-css-only [flex-gt-sm="70"] {
    max-width: 70%;
    max-height: 100%; }
  .layout-gt-sm-column > .flex-gt-sm-70, .md-css-only [layout="column"] > .md-css-only [flex-gt-sm="70"] {
    max-height: 70%;
    max-width: 100%; }
  .flex-gt-sm-75, .md-css-only [flex-gt-sm="75"] {
    -webkit-flex: 0 0 75%;
        -ms-flex: 0 0 75%;
            flex: 0 0 75%; }
  .layout-gt-sm-row > .flex-gt-sm-75, .md-css-only [layout="row"] > .md-css-only [flex-gt-sm="75"] {
    max-width: 75%;
    max-height: 100%; }
  .layout-gt-sm-column > .flex-gt-sm-75, .md-css-only [layout="column"] > .md-css-only [flex-gt-sm="75"] {
    max-height: 75%;
    max-width: 100%; }
  .flex-gt-sm-80, .md-css-only [flex-gt-sm="80"] {
    -webkit-flex: 0 0 80%;
        -ms-flex: 0 0 80%;
            flex: 0 0 80%; }
  .layout-gt-sm-row > .flex-gt-sm-80, .md-css-only [layout="row"] > .md-css-only [flex-gt-sm="80"] {
    max-width: 80%;
    max-height: 100%; }
  .layout-gt-sm-column > .flex-gt-sm-80, .md-css-only [layout="column"] > .md-css-only [flex-gt-sm="80"] {
    max-height: 80%;
    max-width: 100%; }
  .flex-gt-sm-85, .md-css-only [flex-gt-sm="85"] {
    -webkit-flex: 0 0 85%;
        -ms-flex: 0 0 85%;
            flex: 0 0 85%; }
  .layout-gt-sm-row > .flex-gt-sm-85, .md-css-only [layout="row"] > .md-css-only [flex-gt-sm="85"] {
    max-width: 85%;
    max-height: 100%; }
  .layout-gt-sm-column > .flex-gt-sm-85, .md-css-only [layout="column"] > .md-css-only [flex-gt-sm="85"] {
    max-height: 85%;
    max-width: 100%; }
  .flex-gt-sm-90, .md-css-only [flex-gt-sm="90"] {
    -webkit-flex: 0 0 90%;
        -ms-flex: 0 0 90%;
            flex: 0 0 90%; }
  .layout-gt-sm-row > .flex-gt-sm-90, .md-css-only [layout="row"] > .md-css-only [flex-gt-sm="90"] {
    max-width: 90%;
    max-height: 100%; }
  .layout-gt-sm-column > .flex-gt-sm-90, .md-css-only [layout="column"] > .md-css-only [flex-gt-sm="90"] {
    max-height: 90%;
    max-width: 100%; }
  .flex-gt-sm-95, .md-css-only [flex-gt-sm="95"] {
    -webkit-flex: 0 0 95%;
        -ms-flex: 0 0 95%;
            flex: 0 0 95%; }
  .layout-gt-sm-row > .flex-gt-sm-95, .md-css-only [layout="row"] > .md-css-only [flex-gt-sm="95"] {
    max-width: 95%;
    max-height: 100%; }
  .layout-gt-sm-column > .flex-gt-sm-95, .md-css-only [layout="column"] > .md-css-only [flex-gt-sm="95"] {
    max-height: 95%;
    max-width: 100%; }
  .flex-gt-sm-100, .md-css-only [flex-gt-sm="100"] {
    -webkit-flex: 0 0 100%;
        -ms-flex: 0 0 100%;
            flex: 0 0 100%; }
  .layout-gt-sm-row > .flex-gt-sm-100, .md-css-only [layout="row"] > .md-css-only [flex-gt-sm="100"] {
    max-width: 100%;
    max-height: 100%; }
  .layout-gt-sm-column > .flex-gt-sm-100, .md-css-only [layout="column"] > .md-css-only [flex-gt-sm="100"] {
    max-height: 100%;
    max-width: 100%; }
  .flex-gt-sm-33, .flex-gt-sm-34 {
    -webkit-flex: 0 0 33%;
        -ms-flex: 0 0 33%;
            flex: 0 0 33%;
    max-width: 33%;
    max-height: 100%; }
  .flex-gt-sm-66, .flex-gt-sm-67 {
    -webkit-flex: 0 0 67%;
        -ms-flex: 0 0 67%;
            flex: 0 0 67%;
    max-width: 67%;
    max-height: 100%; }
  .layout-gt-sm-row > .flex-gt-sm-33, .layout-gt-sm-row > .flex-gt-sm-34 {
    max-width: 33%;
    max-height: 100%; }
  .layout-gt-sm-row > .flex-gt-sm-66, .layout-gt-sm-row > .flex-gt-sm-67 {
    max-width: 67%;
    max-height: 100%; }
  .layout-gt-sm-column > .flex-gt-sm-33, .layout-gt-sm-column > .flex-gt-sm-34 {
    max-height: 33%;
    max-width: 100%; }
  .layout-gt-sm-column > .flex-gt-sm-66, .layout-gt-sm-column > .flex-gt-sm-67 {
    max-height: 67%;
    max-width: 100%; } }

@media (min-width: 600px) and (max-width: 959px) {
  .hide:not(.show-gt-sm):not(.show-md):not(.show), .hide-gt-sm:not(.show-gt-sm):not(.show-md):not(.show) {
    display: none; }
  .hide-md:not(.show-md):not(.show) {
    display: none; }
  .layout-md {
    box-sizing: border-box;
    display: -webkit-flex;
    display: -ms-flexbox;
    display: flex; }
  .layout-md-column, .md-css-only [layout-md=column] {
    -webkit-flex-direction: column;
        -ms-flex-direction: column;
            flex-direction: column; }
  .layout-md-row, .md-css-only [layout-md=row] {
    -webkit-flex-direction: row;
        -ms-flex-direction: row;
            flex-direction: row;
    -webkit-flex-wrap: wrap;
        -ms-flex-wrap: wrap;
            flex-wrap: wrap; }
  .flex-md {
    box-sizing: border-box;
    -webkit-flex: 1;
        -ms-flex: 1;
            flex: 1; }
  .flex-md-5, .md-css-only [flex-md="5"] {
    -webkit-flex: 0 0 5%;
        -ms-flex: 0 0 5%;
            flex: 0 0 5%; }
  .layout-md-row > .flex-md-5, .md-css-only [layout="row"] > .md-css-only [flex-md="5"] {
    max-width: 5%;
    max-height: 100%; }
  .layout-md-column > .flex-md-5, .md-css-only [layout="column"] > .md-css-only [flex-md="5"] {
    max-height: 5%;
    max-width: 100%; }
  .flex-md-10, .md-css-only [flex-md="10"] {
    -webkit-flex: 0 0 10%;
        -ms-flex: 0 0 10%;
            flex: 0 0 10%; }
  .layout-md-row > .flex-md-10, .md-css-only [layout="row"] > .md-css-only [flex-md="10"] {
    max-width: 10%;
    max-height: 100%; }
  .layout-md-column > .flex-md-10, .md-css-only [layout="column"] > .md-css-only [flex-md="10"] {
    max-height: 10%;
    max-width: 100%; }
  .flex-md-15, .md-css-only [flex-md="15"] {
    -webkit-flex: 0 0 15%;
        -ms-flex: 0 0 15%;
            flex: 0 0 15%; }
  .layout-md-row > .flex-md-15, .md-css-only [layout="row"] > .md-css-only [flex-md="15"] {
    max-width: 15%;
    max-height: 100%; }
  .layout-md-column > .flex-md-15, .md-css-only [layout="column"] > .md-css-only [flex-md="15"] {
    max-height: 15%;
    max-width: 100%; }
  .flex-md-20, .md-css-only [flex-md="20"] {
    -webkit-flex: 0 0 20%;
        -ms-flex: 0 0 20%;
            flex: 0 0 20%; }
  .layout-md-row > .flex-md-20, .md-css-only [layout="row"] > .md-css-only [flex-md="20"] {
    max-width: 20%;
    max-height: 100%; }
  .layout-md-column > .flex-md-20, .md-css-only [layout="column"] > .md-css-only [flex-md="20"] {
    max-height: 20%;
    max-width: 100%; }
  .flex-md-25, .md-css-only [flex-md="25"] {
    -webkit-flex: 0 0 25%;
        -ms-flex: 0 0 25%;
            flex: 0 0 25%; }
  .layout-md-row > .flex-md-25, .md-css-only [layout="row"] > .md-css-only [flex-md="25"] {
    max-width: 25%;
    max-height: 100%; }
  .layout-md-column > .flex-md-25, .md-css-only [layout="column"] > .md-css-only [flex-md="25"] {
    max-height: 25%;
    max-width: 100%; }
  .flex-md-30, .md-css-only [flex-md="30"] {
    -webkit-flex: 0 0 30%;
        -ms-flex: 0 0 30%;
            flex: 0 0 30%; }
  .layout-md-row > .flex-md-30, .md-css-only [layout="row"] > .md-css-only [flex-md="30"] {
    max-width: 30%;
    max-height: 100%; }
  .layout-md-column > .flex-md-30, .md-css-only [layout="column"] > .md-css-only [flex-md="30"] {
    max-height: 30%;
    max-width: 100%; }
  .flex-md-35, .md-css-only [flex-md="35"] {
    -webkit-flex: 0 0 35%;
        -ms-flex: 0 0 35%;
            flex: 0 0 35%; }
  .layout-md-row > .flex-md-35, .md-css-only [layout="row"] > .md-css-only [flex-md="35"] {
    max-width: 35%;
    max-height: 100%; }
  .layout-md-column > .flex-md-35, .md-css-only [layout="column"] > .md-css-only [flex-md="35"] {
    max-height: 35%;
    max-width: 100%; }
  .flex-md-40, .md-css-only [flex-md="40"] {
    -webkit-flex: 0 0 40%;
        -ms-flex: 0 0 40%;
            flex: 0 0 40%; }
  .layout-md-row > .flex-md-40, .md-css-only [layout="row"] > .md-css-only [flex-md="40"] {
    max-width: 40%;
    max-height: 100%; }
  .layout-md-column > .flex-md-40, .md-css-only [layout="column"] > .md-css-only [flex-md="40"] {
    max-height: 40%;
    max-width: 100%; }
  .flex-md-45, .md-css-only [flex-md="45"] {
    -webkit-flex: 0 0 45%;
        -ms-flex: 0 0 45%;
            flex: 0 0 45%; }
  .layout-md-row > .flex-md-45, .md-css-only [layout="row"] > .md-css-only [flex-md="45"] {
    max-width: 45%;
    max-height: 100%; }
  .layout-md-column > .flex-md-45, .md-css-only [layout="column"] > .md-css-only [flex-md="45"] {
    max-height: 45%;
    max-width: 100%; }
  .flex-md-50, .md-css-only [flex-md="50"] {
    -webkit-flex: 0 0 50%;
        -ms-flex: 0 0 50%;
            flex: 0 0 50%; }
  .layout-md-row > .flex-md-50, .md-css-only [layout="row"] > .md-css-only [flex-md="50"] {
    max-width: 50%;
    max-height: 100%; }
  .layout-md-column > .flex-md-50, .md-css-only [layout="column"] > .md-css-only [flex-md="50"] {
    max-height: 50%;
    max-width: 100%; }
  .flex-md-55, .md-css-only [flex-md="55"] {
    -webkit-flex: 0 0 55%;
        -ms-flex: 0 0 55%;
            flex: 0 0 55%; }
  .layout-md-row > .flex-md-55, .md-css-only [layout="row"] > .md-css-only [flex-md="55"] {
    max-width: 55%;
    max-height: 100%; }
  .layout-md-column > .flex-md-55, .md-css-only [layout="column"] > .md-css-only [flex-md="55"] {
    max-height: 55%;
    max-width: 100%; }
  .flex-md-60, .md-css-only [flex-md="60"] {
    -webkit-flex: 0 0 60%;
        -ms-flex: 0 0 60%;
            flex: 0 0 60%; }
  .layout-md-row > .flex-md-60, .md-css-only [layout="row"] > .md-css-only [flex-md="60"] {
    max-width: 60%;
    max-height: 100%; }
  .layout-md-column > .flex-md-60, .md-css-only [layout="column"] > .md-css-only [flex-md="60"] {
    max-height: 60%;
    max-width: 100%; }
  .flex-md-65, .md-css-only [flex-md="65"] {
    -webkit-flex: 0 0 65%;
        -ms-flex: 0 0 65%;
            flex: 0 0 65%; }
  .layout-md-row > .flex-md-65, .md-css-only [layout="row"] > .md-css-only [flex-md="65"] {
    max-width: 65%;
    max-height: 100%; }
  .layout-md-column > .flex-md-65, .md-css-only [layout="column"] > .md-css-only [flex-md="65"] {
    max-height: 65%;
    max-width: 100%; }
  .flex-md-70, .md-css-only [flex-md="70"] {
    -webkit-flex: 0 0 70%;
        -ms-flex: 0 0 70%;
            flex: 0 0 70%; }
  .layout-md-row > .flex-md-70, .md-css-only [layout="row"] > .md-css-only [flex-md="70"] {
    max-width: 70%;
    max-height: 100%; }
  .layout-md-column > .flex-md-70, .md-css-only [layout="column"] > .md-css-only [flex-md="70"] {
    max-height: 70%;
    max-width: 100%; }
  .flex-md-75, .md-css-only [flex-md="75"] {
    -webkit-flex: 0 0 75%;
        -ms-flex: 0 0 75%;
            flex: 0 0 75%; }
  .layout-md-row > .flex-md-75, .md-css-only [layout="row"] > .md-css-only [flex-md="75"] {
    max-width: 75%;
    max-height: 100%; }
  .layout-md-column > .flex-md-75, .md-css-only [layout="column"] > .md-css-only [flex-md="75"] {
    max-height: 75%;
    max-width: 100%; }
  .flex-md-80, .md-css-only [flex-md="80"] {
    -webkit-flex: 0 0 80%;
        -ms-flex: 0 0 80%;
            flex: 0 0 80%; }
  .layout-md-row > .flex-md-80, .md-css-only [layout="row"] > .md-css-only [flex-md="80"] {
    max-width: 80%;
    max-height: 100%; }
  .layout-md-column > .flex-md-80, .md-css-only [layout="column"] > .md-css-only [flex-md="80"] {
    max-height: 80%;
    max-width: 100%; }
  .flex-md-85, .md-css-only [flex-md="85"] {
    -webkit-flex: 0 0 85%;
        -ms-flex: 0 0 85%;
            flex: 0 0 85%; }
  .layout-md-row > .flex-md-85, .md-css-only [layout="row"] > .md-css-only [flex-md="85"] {
    max-width: 85%;
    max-height: 100%; }
  .layout-md-column > .flex-md-85, .md-css-only [layout="column"] > .md-css-only [flex-md="85"] {
    max-height: 85%;
    max-width: 100%; }
  .flex-md-90, .md-css-only [flex-md="90"] {
    -webkit-flex: 0 0 90%;
        -ms-flex: 0 0 90%;
            flex: 0 0 90%; }
  .layout-md-row > .flex-md-90, .md-css-only [layout="row"] > .md-css-only [flex-md="90"] {
    max-width: 90%;
    max-height: 100%; }
  .layout-md-column > .flex-md-90, .md-css-only [layout="column"] > .md-css-only [flex-md="90"] {
    max-height: 90%;
    max-width: 100%; }
  .flex-md-95, .md-css-only [flex-md="95"] {
    -webkit-flex: 0 0 95%;
        -ms-flex: 0 0 95%;
            flex: 0 0 95%; }
  .layout-md-row > .flex-md-95, .md-css-only [layout="row"] > .md-css-only [flex-md="95"] {
    max-width: 95%;
    max-height: 100%; }
  .layout-md-column > .flex-md-95, .md-css-only [layout="column"] > .md-css-only [flex-md="95"] {
    max-height: 95%;
    max-width: 100%; }
  .flex-md-100, .md-css-only [flex-md="100"] {
    -webkit-flex: 0 0 100%;
        -ms-flex: 0 0 100%;
            flex: 0 0 100%; }
  .layout-md-row > .flex-md-100, .md-css-only [layout="row"] > .md-css-only [flex-md="100"] {
    max-width: 100%;
    max-height: 100%; }
  .layout-md-column > .flex-md-100, .md-css-only [layout="column"] > .md-css-only [flex-md="100"] {
    max-height: 100%;
    max-width: 100%; }
  .flex-md-33, .flex-md-34 {
    -webkit-flex: 0 0 33%;
        -ms-flex: 0 0 33%;
            flex: 0 0 33%;
    max-width: 33%;
    max-height: 100%; }
  .flex-md-66, .flex-md-67 {
    -webkit-flex: 0 0 67%;
        -ms-flex: 0 0 67%;
            flex: 0 0 67%;
    max-width: 67%;
    max-height: 100%; }
  .layout-md-row > .flex-md-33, .layout-md-row > .flex-md-34 {
    max-width: 33%;
    max-height: 100%; }
  .layout-md-row > .flex-md-66, .layout-md-row > .flex-md-67 {
    max-width: 67%;
    max-height: 100%; }
  .layout-md-column > .flex-md-33, .layout-md-column > .flex-md-34 {
    max-height: 33%;
    max-width: 100%; }
  .layout-md-column > .flex-md-66, .layout-md-column > .flex-md-67 {
    max-height: 67%;
    max-width: 100%; } }

@media (min-width: 960px) {
  .layout-gt-md {
    box-sizing: border-box;
    display: -webkit-flex;
    display: -ms-flexbox;
    display: flex; }
  .layout-gt-md-column, .md-css-only [layout-gt-md=column] {
    -webkit-flex-direction: column;
        -ms-flex-direction: column;
            flex-direction: column; }
  .layout-gt-md-row, .md-css-only [layout-gt-md=row] {
    -webkit-flex-direction: row;
        -ms-flex-direction: row;
            flex-direction: row;
    -webkit-flex-wrap: wrap;
        -ms-flex-wrap: wrap;
            flex-wrap: wrap; }
  .flex-gt-md {
    box-sizing: border-box;
    -webkit-flex: 1;
        -ms-flex: 1;
            flex: 1; }
  .flex-gt-md-5, .md-css-only [flex-gt-md="5"] {
    -webkit-flex: 0 0 5%;
        -ms-flex: 0 0 5%;
            flex: 0 0 5%; }
  .layout-gt-md-row > .flex-gt-md-5, .md-css-only [layout="row"] > .md-css-only [flex-gt-md="5"] {
    max-width: 5%;
    max-height: 100%; }
  .layout-gt-md-column > .flex-gt-md-5, .md-css-only [layout="column"] > .md-css-only [flex-gt-md="5"] {
    max-height: 5%;
    max-width: 100%; }
  .flex-gt-md-10, .md-css-only [flex-gt-md="10"] {
    -webkit-flex: 0 0 10%;
        -ms-flex: 0 0 10%;
            flex: 0 0 10%; }
  .layout-gt-md-row > .flex-gt-md-10, .md-css-only [layout="row"] > .md-css-only [flex-gt-md="10"] {
    max-width: 10%;
    max-height: 100%; }
  .layout-gt-md-column > .flex-gt-md-10, .md-css-only [layout="column"] > .md-css-only [flex-gt-md="10"] {
    max-height: 10%;
    max-width: 100%; }
  .flex-gt-md-15, .md-css-only [flex-gt-md="15"] {
    -webkit-flex: 0 0 15%;
        -ms-flex: 0 0 15%;
            flex: 0 0 15%; }
  .layout-gt-md-row > .flex-gt-md-15, .md-css-only [layout="row"] > .md-css-only [flex-gt-md="15"] {
    max-width: 15%;
    max-height: 100%; }
  .layout-gt-md-column > .flex-gt-md-15, .md-css-only [layout="column"] > .md-css-only [flex-gt-md="15"] {
    max-height: 15%;
    max-width: 100%; }
  .flex-gt-md-20, .md-css-only [flex-gt-md="20"] {
    -webkit-flex: 0 0 20%;
        -ms-flex: 0 0 20%;
            flex: 0 0 20%; }
  .layout-gt-md-row > .flex-gt-md-20, .md-css-only [layout="row"] > .md-css-only [flex-gt-md="20"] {
    max-width: 20%;
    max-height: 100%; }
  .layout-gt-md-column > .flex-gt-md-20, .md-css-only [layout="column"] > .md-css-only [flex-gt-md="20"] {
    max-height: 20%;
    max-width: 100%; }
  .flex-gt-md-25, .md-css-only [flex-gt-md="25"] {
    -webkit-flex: 0 0 25%;
        -ms-flex: 0 0 25%;
            flex: 0 0 25%; }
  .layout-gt-md-row > .flex-gt-md-25, .md-css-only [layout="row"] > .md-css-only [flex-gt-md="25"] {
    max-width: 25%;
    max-height: 100%; }
  .layout-gt-md-column > .flex-gt-md-25, .md-css-only [layout="column"] > .md-css-only [flex-gt-md="25"] {
    max-height: 25%;
    max-width: 100%; }
  .flex-gt-md-30, .md-css-only [flex-gt-md="30"] {
    -webkit-flex: 0 0 30%;
        -ms-flex: 0 0 30%;
            flex: 0 0 30%; }
  .layout-gt-md-row > .flex-gt-md-30, .md-css-only [layout="row"] > .md-css-only [flex-gt-md="30"] {
    max-width: 30%;
    max-height: 100%; }
  .layout-gt-md-column > .flex-gt-md-30, .md-css-only [layout="column"] > .md-css-only [flex-gt-md="30"] {
    max-height: 30%;
    max-width: 100%; }
  .flex-gt-md-35, .md-css-only [flex-gt-md="35"] {
    -webkit-flex: 0 0 35%;
        -ms-flex: 0 0 35%;
            flex: 0 0 35%; }
  .layout-gt-md-row > .flex-gt-md-35, .md-css-only [layout="row"] > .md-css-only [flex-gt-md="35"] {
    max-width: 35%;
    max-height: 100%; }
  .layout-gt-md-column > .flex-gt-md-35, .md-css-only [layout="column"] > .md-css-only [flex-gt-md="35"] {
    max-height: 35%;
    max-width: 100%; }
  .flex-gt-md-40, .md-css-only [flex-gt-md="40"] {
    -webkit-flex: 0 0 40%;
        -ms-flex: 0 0 40%;
            flex: 0 0 40%; }
  .layout-gt-md-row > .flex-gt-md-40, .md-css-only [layout="row"] > .md-css-only [flex-gt-md="40"] {
    max-width: 40%;
    max-height: 100%; }
  .layout-gt-md-column > .flex-gt-md-40, .md-css-only [layout="column"] > .md-css-only [flex-gt-md="40"] {
    max-height: 40%;
    max-width: 100%; }
  .flex-gt-md-45, .md-css-only [flex-gt-md="45"] {
    -webkit-flex: 0 0 45%;
        -ms-flex: 0 0 45%;
            flex: 0 0 45%; }
  .layout-gt-md-row > .flex-gt-md-45, .md-css-only [layout="row"] > .md-css-only [flex-gt-md="45"] {
    max-width: 45%;
    max-height: 100%; }
  .layout-gt-md-column > .flex-gt-md-45, .md-css-only [layout="column"] > .md-css-only [flex-gt-md="45"] {
    max-height: 45%;
    max-width: 100%; }
  .flex-gt-md-50, .md-css-only [flex-gt-md="50"] {
    -webkit-flex: 0 0 50%;
        -ms-flex: 0 0 50%;
            flex: 0 0 50%; }
  .layout-gt-md-row > .flex-gt-md-50, .md-css-only [layout="row"] > .md-css-only [flex-gt-md="50"] {
    max-width: 50%;
    max-height: 100%; }
  .layout-gt-md-column > .flex-gt-md-50, .md-css-only [layout="column"] > .md-css-only [flex-gt-md="50"] {
    max-height: 50%;
    max-width: 100%; }
  .flex-gt-md-55, .md-css-only [flex-gt-md="55"] {
    -webkit-flex: 0 0 55%;
        -ms-flex: 0 0 55%;
            flex: 0 0 55%; }
  .layout-gt-md-row > .flex-gt-md-55, .md-css-only [layout="row"] > .md-css-only [flex-gt-md="55"] {
    max-width: 55%;
    max-height: 100%; }
  .layout-gt-md-column > .flex-gt-md-55, .md-css-only [layout="column"] > .md-css-only [flex-gt-md="55"] {
    max-height: 55%;
    max-width: 100%; }
  .flex-gt-md-60, .md-css-only [flex-gt-md="60"] {
    -webkit-flex: 0 0 60%;
        -ms-flex: 0 0 60%;
            flex: 0 0 60%; }
  .layout-gt-md-row > .flex-gt-md-60, .md-css-only [layout="row"] > .md-css-only [flex-gt-md="60"] {
    max-width: 60%;
    max-height: 100%; }
  .layout-gt-md-column > .flex-gt-md-60, .md-css-only [layout="column"] > .md-css-only [flex-gt-md="60"] {
    max-height: 60%;
    max-width: 100%; }
  .flex-gt-md-65, .md-css-only [flex-gt-md="65"] {
    -webkit-flex: 0 0 65%;
        -ms-flex: 0 0 65%;
            flex: 0 0 65%; }
  .layout-gt-md-row > .flex-gt-md-65, .md-css-only [layout="row"] > .md-css-only [flex-gt-md="65"] {
    max-width: 65%;
    max-height: 100%; }
  .layout-gt-md-column > .flex-gt-md-65, .md-css-only [layout="column"] > .md-css-only [flex-gt-md="65"] {
    max-height: 65%;
    max-width: 100%; }
  .flex-gt-md-70, .md-css-only [flex-gt-md="70"] {
    -webkit-flex: 0 0 70%;
        -ms-flex: 0 0 70%;
            flex: 0 0 70%; }
  .layout-gt-md-row > .flex-gt-md-70, .md-css-only [layout="row"] > .md-css-only [flex-gt-md="70"] {
    max-width: 70%;
    max-height: 100%; }
  .layout-gt-md-column > .flex-gt-md-70, .md-css-only [layout="column"] > .md-css-only [flex-gt-md="70"] {
    max-height: 70%;
    max-width: 100%; }
  .flex-gt-md-75, .md-css-only [flex-gt-md="75"] {
    -webkit-flex: 0 0 75%;
        -ms-flex: 0 0 75%;
            flex: 0 0 75%; }
  .layout-gt-md-row > .flex-gt-md-75, .md-css-only [layout="row"] > .md-css-only [flex-gt-md="75"] {
    max-width: 75%;
    max-height: 100%; }
  .layout-gt-md-column > .flex-gt-md-75, .md-css-only [layout="column"] > .md-css-only [flex-gt-md="75"] {
    max-height: 75%;
    max-width: 100%; }
  .flex-gt-md-80, .md-css-only [flex-gt-md="80"] {
    -webkit-flex: 0 0 80%;
        -ms-flex: 0 0 80%;
            flex: 0 0 80%; }
  .layout-gt-md-row > .flex-gt-md-80, .md-css-only [layout="row"] > .md-css-only [flex-gt-md="80"] {
    max-width: 80%;
    max-height: 100%; }
  .layout-gt-md-column > .flex-gt-md-80, .md-css-only [layout="column"] > .md-css-only [flex-gt-md="80"] {
    max-height: 80%;
    max-width: 100%; }
  .flex-gt-md-85, .md-css-only [flex-gt-md="85"] {
    -webkit-flex: 0 0 85%;
        -ms-flex: 0 0 85%;
            flex: 0 0 85%; }
  .layout-gt-md-row > .flex-gt-md-85, .md-css-only [layout="row"] > .md-css-only [flex-gt-md="85"] {
    max-width: 85%;
    max-height: 100%; }
  .layout-gt-md-column > .flex-gt-md-85, .md-css-only [layout="column"] > .md-css-only [flex-gt-md="85"] {
    max-height: 85%;
    max-width: 100%; }
  .flex-gt-md-90, .md-css-only [flex-gt-md="90"] {
    -webkit-flex: 0 0 90%;
        -ms-flex: 0 0 90%;
            flex: 0 0 90%; }
  .layout-gt-md-row > .flex-gt-md-90, .md-css-only [layout="row"] > .md-css-only [flex-gt-md="90"] {
    max-width: 90%;
    max-height: 100%; }
  .layout-gt-md-column > .flex-gt-md-90, .md-css-only [layout="column"] > .md-css-only [flex-gt-md="90"] {
    max-height: 90%;
    max-width: 100%; }
  .flex-gt-md-95, .md-css-only [flex-gt-md="95"] {
    -webkit-flex: 0 0 95%;
        -ms-flex: 0 0 95%;
            flex: 0 0 95%; }
  .layout-gt-md-row > .flex-gt-md-95, .md-css-only [layout="row"] > .md-css-only [flex-gt-md="95"] {
    max-width: 95%;
    max-height: 100%; }
  .layout-gt-md-column > .flex-gt-md-95, .md-css-only [layout="column"] > .md-css-only [flex-gt-md="95"] {
    max-height: 95%;
    max-width: 100%; }
  .flex-gt-md-100, .md-css-only [flex-gt-md="100"] {
    -webkit-flex: 0 0 100%;
        -ms-flex: 0 0 100%;
            flex: 0 0 100%; }
  .layout-gt-md-row > .flex-gt-md-100, .md-css-only [layout="row"] > .md-css-only [flex-gt-md="100"] {
    max-width: 100%;
    max-height: 100%; }
  .layout-gt-md-column > .flex-gt-md-100, .md-css-only [layout="column"] > .md-css-only [flex-gt-md="100"] {
    max-height: 100%;
    max-width: 100%; }
  .flex-gt-md-33, .flex-gt-md-34 {
    -webkit-flex: 0 0 33%;
        -ms-flex: 0 0 33%;
            flex: 0 0 33%;
    max-width: 33%;
    max-height: 100%; }
  .flex-gt-md-66, .flex-gt-md-67 {
    -webkit-flex: 0 0 67%;
        -ms-flex: 0 0 67%;
            flex: 0 0 67%;
    max-width: 67%;
    max-height: 100%; }
  .layout-gt-md-row > .flex-gt-md-33, .layout-gt-md-row > .flex-gt-md-34 {
    max-width: 33%;
    max-height: 100%; }
  .layout-gt-md-row > .flex-gt-md-66, .layout-gt-md-row > .flex-gt-md-67 {
    max-width: 67%;
    max-height: 100%; }
  .layout-gt-md-column > .flex-gt-md-33, .layout-gt-md-column > .flex-gt-md-34 {
    max-height: 33%;
    max-width: 100%; }
  .layout-gt-md-column > .flex-gt-md-66, .layout-gt-md-column > .flex-gt-md-67 {
    max-height: 67%;
    max-width: 100%; } }

@media (min-width: 960px) and (max-width: 1199px) {
  .hide:not(.show-gt-sm):not(.show-gt-md):not(.show-lg):not(.show), .hide-gt-sm:not(.show-gt-sm):not(.show-gt-md):not(.show-lg):not(.show), .hide-gt-md:not(.show-gt-sm):not(.show-gt-md):not(.show-lg):not(.show) {
    display: none; }
  .hide-lg:not(.show-lg):not(.show) {
    display: none; }
  .layout-lg {
    box-sizing: border-box;
    display: -webkit-flex;
    display: -ms-flexbox;
    display: flex; }
  .layout-lg-column, .md-css-only [layout-lg=column] {
    -webkit-flex-direction: column;
        -ms-flex-direction: column;
            flex-direction: column; }
  .layout-lg-row, .md-css-only [layout-lg=row] {
    -webkit-flex-direction: row;
        -ms-flex-direction: row;
            flex-direction: row;
    -webkit-flex-wrap: wrap;
        -ms-flex-wrap: wrap;
            flex-wrap: wrap; }
  .flex-lg {
    box-sizing: border-box;
    -webkit-flex: 1;
        -ms-flex: 1;
            flex: 1; }
  .flex-lg-5, .md-css-only [flex-lg="5"] {
    -webkit-flex: 0 0 5%;
        -ms-flex: 0 0 5%;
            flex: 0 0 5%; }
  .layout-lg-row > .flex-lg-5, .md-css-only [layout="row"] > .md-css-only [flex-lg="5"] {
    max-width: 5%;
    max-height: 100%; }
  .layout-lg-column > .flex-lg-5, .md-css-only [layout="column"] > .md-css-only [flex-lg="5"] {
    max-height: 5%;
    max-width: 100%; }
  .flex-lg-10, .md-css-only [flex-lg="10"] {
    -webkit-flex: 0 0 10%;
        -ms-flex: 0 0 10%;
            flex: 0 0 10%; }
  .layout-lg-row > .flex-lg-10, .md-css-only [layout="row"] > .md-css-only [flex-lg="10"] {
    max-width: 10%;
    max-height: 100%; }
  .layout-lg-column > .flex-lg-10, .md-css-only [layout="column"] > .md-css-only [flex-lg="10"] {
    max-height: 10%;
    max-width: 100%; }
  .flex-lg-15, .md-css-only [flex-lg="15"] {
    -webkit-flex: 0 0 15%;
        -ms-flex: 0 0 15%;
            flex: 0 0 15%; }
  .layout-lg-row > .flex-lg-15, .md-css-only [layout="row"] > .md-css-only [flex-lg="15"] {
    max-width: 15%;
    max-height: 100%; }
  .layout-lg-column > .flex-lg-15, .md-css-only [layout="column"] > .md-css-only [flex-lg="15"] {
    max-height: 15%;
    max-width: 100%; }
  .flex-lg-20, .md-css-only [flex-lg="20"] {
    -webkit-flex: 0 0 20%;
        -ms-flex: 0 0 20%;
            flex: 0 0 20%; }
  .layout-lg-row > .flex-lg-20, .md-css-only [layout="row"] > .md-css-only [flex-lg="20"] {
    max-width: 20%;
    max-height: 100%; }
  .layout-lg-column > .flex-lg-20, .md-css-only [layout="column"] > .md-css-only [flex-lg="20"] {
    max-height: 20%;
    max-width: 100%; }
  .flex-lg-25, .md-css-only [flex-lg="25"] {
    -webkit-flex: 0 0 25%;
        -ms-flex: 0 0 25%;
            flex: 0 0 25%; }
  .layout-lg-row > .flex-lg-25, .md-css-only [layout="row"] > .md-css-only [flex-lg="25"] {
    max-width: 25%;
    max-height: 100%; }
  .layout-lg-column > .flex-lg-25, .md-css-only [layout="column"] > .md-css-only [flex-lg="25"] {
    max-height: 25%;
    max-width: 100%; }
  .flex-lg-30, .md-css-only [flex-lg="30"] {
    -webkit-flex: 0 0 30%;
        -ms-flex: 0 0 30%;
            flex: 0 0 30%; }
  .layout-lg-row > .flex-lg-30, .md-css-only [layout="row"] > .md-css-only [flex-lg="30"] {
    max-width: 30%;
    max-height: 100%; }
  .layout-lg-column > .flex-lg-30, .md-css-only [layout="column"] > .md-css-only [flex-lg="30"] {
    max-height: 30%;
    max-width: 100%; }
  .flex-lg-35, .md-css-only [flex-lg="35"] {
    -webkit-flex: 0 0 35%;
        -ms-flex: 0 0 35%;
            flex: 0 0 35%; }
  .layout-lg-row > .flex-lg-35, .md-css-only [layout="row"] > .md-css-only [flex-lg="35"] {
    max-width: 35%;
    max-height: 100%; }
  .layout-lg-column > .flex-lg-35, .md-css-only [layout="column"] > .md-css-only [flex-lg="35"] {
    max-height: 35%;
    max-width: 100%; }
  .flex-lg-40, .md-css-only [flex-lg="40"] {
    -webkit-flex: 0 0 40%;
        -ms-flex: 0 0 40%;
            flex: 0 0 40%; }
  .layout-lg-row > .flex-lg-40, .md-css-only [layout="row"] > .md-css-only [flex-lg="40"] {
    max-width: 40%;
    max-height: 100%; }
  .layout-lg-column > .flex-lg-40, .md-css-only [layout="column"] > .md-css-only [flex-lg="40"] {
    max-height: 40%;
    max-width: 100%; }
  .flex-lg-45, .md-css-only [flex-lg="45"] {
    -webkit-flex: 0 0 45%;
        -ms-flex: 0 0 45%;
            flex: 0 0 45%; }
  .layout-lg-row > .flex-lg-45, .md-css-only [layout="row"] > .md-css-only [flex-lg="45"] {
    max-width: 45%;
    max-height: 100%; }
  .layout-lg-column > .flex-lg-45, .md-css-only [layout="column"] > .md-css-only [flex-lg="45"] {
    max-height: 45%;
    max-width: 100%; }
  .flex-lg-50, .md-css-only [flex-lg="50"] {
    -webkit-flex: 0 0 50%;
        -ms-flex: 0 0 50%;
            flex: 0 0 50%; }
  .layout-lg-row > .flex-lg-50, .md-css-only [layout="row"] > .md-css-only [flex-lg="50"] {
    max-width: 50%;
    max-height: 100%; }
  .layout-lg-column > .flex-lg-50, .md-css-only [layout="column"] > .md-css-only [flex-lg="50"] {
    max-height: 50%;
    max-width: 100%; }
  .flex-lg-55, .md-css-only [flex-lg="55"] {
    -webkit-flex: 0 0 55%;
        -ms-flex: 0 0 55%;
            flex: 0 0 55%; }
  .layout-lg-row > .flex-lg-55, .md-css-only [layout="row"] > .md-css-only [flex-lg="55"] {
    max-width: 55%;
    max-height: 100%; }
  .layout-lg-column > .flex-lg-55, .md-css-only [layout="column"] > .md-css-only [flex-lg="55"] {
    max-height: 55%;
    max-width: 100%; }
  .flex-lg-60, .md-css-only [flex-lg="60"] {
    -webkit-flex: 0 0 60%;
        -ms-flex: 0 0 60%;
            flex: 0 0 60%; }
  .layout-lg-row > .flex-lg-60, .md-css-only [layout="row"] > .md-css-only [flex-lg="60"] {
    max-width: 60%;
    max-height: 100%; }
  .layout-lg-column > .flex-lg-60, .md-css-only [layout="column"] > .md-css-only [flex-lg="60"] {
    max-height: 60%;
    max-width: 100%; }
  .flex-lg-65, .md-css-only [flex-lg="65"] {
    -webkit-flex: 0 0 65%;
        -ms-flex: 0 0 65%;
            flex: 0 0 65%; }
  .layout-lg-row > .flex-lg-65, .md-css-only [layout="row"] > .md-css-only [flex-lg="65"] {
    max-width: 65%;
    max-height: 100%; }
  .layout-lg-column > .flex-lg-65, .md-css-only [layout="column"] > .md-css-only [flex-lg="65"] {
    max-height: 65%;
    max-width: 100%; }
  .flex-lg-70, .md-css-only [flex-lg="70"] {
    -webkit-flex: 0 0 70%;
        -ms-flex: 0 0 70%;
            flex: 0 0 70%; }
  .layout-lg-row > .flex-lg-70, .md-css-only [layout="row"] > .md-css-only [flex-lg="70"] {
    max-width: 70%;
    max-height: 100%; }
  .layout-lg-column > .flex-lg-70, .md-css-only [layout="column"] > .md-css-only [flex-lg="70"] {
    max-height: 70%;
    max-width: 100%; }
  .flex-lg-75, .md-css-only [flex-lg="75"] {
    -webkit-flex: 0 0 75%;
        -ms-flex: 0 0 75%;
            flex: 0 0 75%; }
  .layout-lg-row > .flex-lg-75, .md-css-only [layout="row"] > .md-css-only [flex-lg="75"] {
    max-width: 75%;
    max-height: 100%; }
  .layout-lg-column > .flex-lg-75, .md-css-only [layout="column"] > .md-css-only [flex-lg="75"] {
    max-height: 75%;
    max-width: 100%; }
  .flex-lg-80, .md-css-only [flex-lg="80"] {
    -webkit-flex: 0 0 80%;
        -ms-flex: 0 0 80%;
            flex: 0 0 80%; }
  .layout-lg-row > .flex-lg-80, .md-css-only [layout="row"] > .md-css-only [flex-lg="80"] {
    max-width: 80%;
    max-height: 100%; }
  .layout-lg-column > .flex-lg-80, .md-css-only [layout="column"] > .md-css-only [flex-lg="80"] {
    max-height: 80%;
    max-width: 100%; }
  .flex-lg-85, .md-css-only [flex-lg="85"] {
    -webkit-flex: 0 0 85%;
        -ms-flex: 0 0 85%;
            flex: 0 0 85%; }
  .layout-lg-row > .flex-lg-85, .md-css-only [layout="row"] > .md-css-only [flex-lg="85"] {
    max-width: 85%;
    max-height: 100%; }
  .layout-lg-column > .flex-lg-85, .md-css-only [layout="column"] > .md-css-only [flex-lg="85"] {
    max-height: 85%;
    max-width: 100%; }
  .flex-lg-90, .md-css-only [flex-lg="90"] {
    -webkit-flex: 0 0 90%;
        -ms-flex: 0 0 90%;
            flex: 0 0 90%; }
  .layout-lg-row > .flex-lg-90, .md-css-only [layout="row"] > .md-css-only [flex-lg="90"] {
    max-width: 90%;
    max-height: 100%; }
  .layout-lg-column > .flex-lg-90, .md-css-only [layout="column"] > .md-css-only [flex-lg="90"] {
    max-height: 90%;
    max-width: 100%; }
  .flex-lg-95, .md-css-only [flex-lg="95"] {
    -webkit-flex: 0 0 95%;
        -ms-flex: 0 0 95%;
            flex: 0 0 95%; }
  .layout-lg-row > .flex-lg-95, .md-css-only [layout="row"] > .md-css-only [flex-lg="95"] {
    max-width: 95%;
    max-height: 100%; }
  .layout-lg-column > .flex-lg-95, .md-css-only [layout="column"] > .md-css-only [flex-lg="95"] {
    max-height: 95%;
    max-width: 100%; }
  .flex-lg-100, .md-css-only [flex-lg="100"] {
    -webkit-flex: 0 0 100%;
        -ms-flex: 0 0 100%;
            flex: 0 0 100%; }
  .layout-lg-row > .flex-lg-100, .md-css-only [layout="row"] > .md-css-only [flex-lg="100"] {
    max-width: 100%;
    max-height: 100%; }
  .layout-lg-column > .flex-lg-100, .md-css-only [layout="column"] > .md-css-only [flex-lg="100"] {
    max-height: 100%;
    max-width: 100%; }
  .flex-lg-33, .flex-lg-34 {
    -webkit-flex: 0 0 33%;
        -ms-flex: 0 0 33%;
            flex: 0 0 33%;
    max-width: 33%;
    max-height: 100%; }
  .flex-lg-66, .flex-lg-67 {
    -webkit-flex: 0 0 67%;
        -ms-flex: 0 0 67%;
            flex: 0 0 67%;
    max-width: 67%;
    max-height: 100%; }
  .layout-lg-row > .flex-lg-33, .layout-lg-row > .flex-lg-34 {
    max-width: 33%;
    max-height: 100%; }
  .layout-lg-row > .flex-lg-66, .layout-lg-row > .flex-lg-67 {
    max-width: 67%;
    max-height: 100%; }
  .layout-lg-column > .flex-lg-33, .layout-lg-column > .flex-lg-34 {
    max-height: 33%;
    max-width: 100%; }
  .layout-lg-column > .flex-lg-66, .layout-lg-column > .flex-lg-67 {
    max-height: 67%;
    max-width: 100%; } }

@media (min-width: 1200px) {
  .hide-gt-sm:not(.show-gt-sm):not(.show-gt-md):not(.show-gt-lg):not(.show), .hide-gt-md:not(.show-gt-sm):not(.show-gt-md):not(.show-gt-lg):not(.show), .hide-gt-lg:not(.show-gt-sm):not(.show-gt-md):not(.show-gt-lg):not(.show), .hide:not(.show-gt-sm):not(.show-gt-md):not(.show-gt-lg):not(.show) {
    display: none; }
  .layout-gt-lg {
    box-sizing: border-box;
    display: -webkit-flex;
    display: -ms-flexbox;
    display: flex; }
  .layout-gt-lg-column, .md-css-only [layout-gt-lg=column] {
    -webkit-flex-direction: column;
        -ms-flex-direction: column;
            flex-direction: column; }
  .layout-gt-lg-row, .md-css-only [layout-gt-lg=row] {
    -webkit-flex-direction: row;
        -ms-flex-direction: row;
            flex-direction: row;
    -webkit-flex-wrap: wrap;
        -ms-flex-wrap: wrap;
            flex-wrap: wrap; }
  .flex-gt-lg {
    box-sizing: border-box;
    -webkit-flex: 1;
        -ms-flex: 1;
            flex: 1; }
  .flex-gt-lg-5, .md-css-only [flex-gt-lg="5"] {
    -webkit-flex: 0 0 5%;
        -ms-flex: 0 0 5%;
            flex: 0 0 5%; }
  .layout-gt-lg-row > .flex-gt-lg-5, .md-css-only [layout="row"] > .md-css-only [flex-gt-lg="5"] {
    max-width: 5%;
    max-height: 100%; }
  .layout-gt-lg-column > .flex-gt-lg-5, .md-css-only [layout="column"] > .md-css-only [flex-gt-lg="5"] {
    max-height: 5%;
    max-width: 100%; }
  .flex-gt-lg-10, .md-css-only [flex-gt-lg="10"] {
    -webkit-flex: 0 0 10%;
        -ms-flex: 0 0 10%;
            flex: 0 0 10%; }
  .layout-gt-lg-row > .flex-gt-lg-10, .md-css-only [layout="row"] > .md-css-only [flex-gt-lg="10"] {
    max-width: 10%;
    max-height: 100%; }
  .layout-gt-lg-column > .flex-gt-lg-10, .md-css-only [layout="column"] > .md-css-only [flex-gt-lg="10"] {
    max-height: 10%;
    max-width: 100%; }
  .flex-gt-lg-15, .md-css-only [flex-gt-lg="15"] {
    -webkit-flex: 0 0 15%;
        -ms-flex: 0 0 15%;
            flex: 0 0 15%; }
  .layout-gt-lg-row > .flex-gt-lg-15, .md-css-only [layout="row"] > .md-css-only [flex-gt-lg="15"] {
    max-width: 15%;
    max-height: 100%; }
  .layout-gt-lg-column > .flex-gt-lg-15, .md-css-only [layout="column"] > .md-css-only [flex-gt-lg="15"] {
    max-height: 15%;
    max-width: 100%; }
  .flex-gt-lg-20, .md-css-only [flex-gt-lg="20"] {
    -webkit-flex: 0 0 20%;
        -ms-flex: 0 0 20%;
            flex: 0 0 20%; }
  .layout-gt-lg-row > .flex-gt-lg-20, .md-css-only [layout="row"] > .md-css-only [flex-gt-lg="20"] {
    max-width: 20%;
    max-height: 100%; }
  .layout-gt-lg-column > .flex-gt-lg-20, .md-css-only [layout="column"] > .md-css-only [flex-gt-lg="20"] {
    max-height: 20%;
    max-width: 100%; }
  .flex-gt-lg-25, .md-css-only [flex-gt-lg="25"] {
    -webkit-flex: 0 0 25%;
        -ms-flex: 0 0 25%;
            flex: 0 0 25%; }
  .layout-gt-lg-row > .flex-gt-lg-25, .md-css-only [layout="row"] > .md-css-only [flex-gt-lg="25"] {
    max-width: 25%;
    max-height: 100%; }
  .layout-gt-lg-column > .flex-gt-lg-25, .md-css-only [layout="column"] > .md-css-only [flex-gt-lg="25"] {
    max-height: 25%;
    max-width: 100%; }
  .flex-gt-lg-30, .md-css-only [flex-gt-lg="30"] {
    -webkit-flex: 0 0 30%;
        -ms-flex: 0 0 30%;
            flex: 0 0 30%; }
  .layout-gt-lg-row > .flex-gt-lg-30, .md-css-only [layout="row"] > .md-css-only [flex-gt-lg="30"] {
    max-width: 30%;
    max-height: 100%; }
  .layout-gt-lg-column > .flex-gt-lg-30, .md-css-only [layout="column"] > .md-css-only [flex-gt-lg="30"] {
    max-height: 30%;
    max-width: 100%; }
  .flex-gt-lg-35, .md-css-only [flex-gt-lg="35"] {
    -webkit-flex: 0 0 35%;
        -ms-flex: 0 0 35%;
            flex: 0 0 35%; }
  .layout-gt-lg-row > .flex-gt-lg-35, .md-css-only [layout="row"] > .md-css-only [flex-gt-lg="35"] {
    max-width: 35%;
    max-height: 100%; }
  .layout-gt-lg-column > .flex-gt-lg-35, .md-css-only [layout="column"] > .md-css-only [flex-gt-lg="35"] {
    max-height: 35%;
    max-width: 100%; }
  .flex-gt-lg-40, .md-css-only [flex-gt-lg="40"] {
    -webkit-flex: 0 0 40%;
        -ms-flex: 0 0 40%;
            flex: 0 0 40%; }
  .layout-gt-lg-row > .flex-gt-lg-40, .md-css-only [layout="row"] > .md-css-only [flex-gt-lg="40"] {
    max-width: 40%;
    max-height: 100%; }
  .layout-gt-lg-column > .flex-gt-lg-40, .md-css-only [layout="column"] > .md-css-only [flex-gt-lg="40"] {
    max-height: 40%;
    max-width: 100%; }
  .flex-gt-lg-45, .md-css-only [flex-gt-lg="45"] {
    -webkit-flex: 0 0 45%;
        -ms-flex: 0 0 45%;
            flex: 0 0 45%; }
  .layout-gt-lg-row > .flex-gt-lg-45, .md-css-only [layout="row"] > .md-css-only [flex-gt-lg="45"] {
    max-width: 45%;
    max-height: 100%; }
  .layout-gt-lg-column > .flex-gt-lg-45, .md-css-only [layout="column"] > .md-css-only [flex-gt-lg="45"] {
    max-height: 45%;
    max-width: 100%; }
  .flex-gt-lg-50, .md-css-only [flex-gt-lg="50"] {
    -webkit-flex: 0 0 50%;
        -ms-flex: 0 0 50%;
            flex: 0 0 50%; }
  .layout-gt-lg-row > .flex-gt-lg-50, .md-css-only [layout="row"] > .md-css-only [flex-gt-lg="50"] {
    max-width: 50%;
    max-height: 100%; }
  .layout-gt-lg-column > .flex-gt-lg-50, .md-css-only [layout="column"] > .md-css-only [flex-gt-lg="50"] {
    max-height: 50%;
    max-width: 100%; }
  .flex-gt-lg-55, .md-css-only [flex-gt-lg="55"] {
    -webkit-flex: 0 0 55%;
        -ms-flex: 0 0 55%;
            flex: 0 0 55%; }
  .layout-gt-lg-row > .flex-gt-lg-55, .md-css-only [layout="row"] > .md-css-only [flex-gt-lg="55"] {
    max-width: 55%;
    max-height: 100%; }
  .layout-gt-lg-column > .flex-gt-lg-55, .md-css-only [layout="column"] > .md-css-only [flex-gt-lg="55"] {
    max-height: 55%;
    max-width: 100%; }
  .flex-gt-lg-60, .md-css-only [flex-gt-lg="60"] {
    -webkit-flex: 0 0 60%;
        -ms-flex: 0 0 60%;
            flex: 0 0 60%; }
  .layout-gt-lg-row > .flex-gt-lg-60, .md-css-only [layout="row"] > .md-css-only [flex-gt-lg="60"] {
    max-width: 60%;
    max-height: 100%; }
  .layout-gt-lg-column > .flex-gt-lg-60, .md-css-only [layout="column"] > .md-css-only [flex-gt-lg="60"] {
    max-height: 60%;
    max-width: 100%; }
  .flex-gt-lg-65, .md-css-only [flex-gt-lg="65"] {
    -webkit-flex: 0 0 65%;
        -ms-flex: 0 0 65%;
            flex: 0 0 65%; }
  .layout-gt-lg-row > .flex-gt-lg-65, .md-css-only [layout="row"] > .md-css-only [flex-gt-lg="65"] {
    max-width: 65%;
    max-height: 100%; }
  .layout-gt-lg-column > .flex-gt-lg-65, .md-css-only [layout="column"] > .md-css-only [flex-gt-lg="65"] {
    max-height: 65%;
    max-width: 100%; }
  .flex-gt-lg-70, .md-css-only [flex-gt-lg="70"] {
    -webkit-flex: 0 0 70%;
        -ms-flex: 0 0 70%;
            flex: 0 0 70%; }
  .layout-gt-lg-row > .flex-gt-lg-70, .md-css-only [layout="row"] > .md-css-only [flex-gt-lg="70"] {
    max-width: 70%;
    max-height: 100%; }
  .layout-gt-lg-column > .flex-gt-lg-70, .md-css-only [layout="column"] > .md-css-only [flex-gt-lg="70"] {
    max-height: 70%;
    max-width: 100%; }
  .flex-gt-lg-75, .md-css-only [flex-gt-lg="75"] {
    -webkit-flex: 0 0 75%;
        -ms-flex: 0 0 75%;
            flex: 0 0 75%; }
  .layout-gt-lg-row > .flex-gt-lg-75, .md-css-only [layout="row"] > .md-css-only [flex-gt-lg="75"] {
    max-width: 75%;
    max-height: 100%; }
  .layout-gt-lg-column > .flex-gt-lg-75, .md-css-only [layout="column"] > .md-css-only [flex-gt-lg="75"] {
    max-height: 75%;
    max-width: 100%; }
  .flex-gt-lg-80, .md-css-only [flex-gt-lg="80"] {
    -webkit-flex: 0 0 80%;
        -ms-flex: 0 0 80%;
            flex: 0 0 80%; }
  .layout-gt-lg-row > .flex-gt-lg-80, .md-css-only [layout="row"] > .md-css-only [flex-gt-lg="80"] {
    max-width: 80%;
    max-height: 100%; }
  .layout-gt-lg-column > .flex-gt-lg-80, .md-css-only [layout="column"] > .md-css-only [flex-gt-lg="80"] {
    max-height: 80%;
    max-width: 100%; }
  .flex-gt-lg-85, .md-css-only [flex-gt-lg="85"] {
    -webkit-flex: 0 0 85%;
        -ms-flex: 0 0 85%;
            flex: 0 0 85%; }
  .layout-gt-lg-row > .flex-gt-lg-85, .md-css-only [layout="row"] > .md-css-only [flex-gt-lg="85"] {
    max-width: 85%;
    max-height: 100%; }
  .layout-gt-lg-column > .flex-gt-lg-85, .md-css-only [layout="column"] > .md-css-only [flex-gt-lg="85"] {
    max-height: 85%;
    max-width: 100%; }
  .flex-gt-lg-90, .md-css-only [flex-gt-lg="90"] {
    -webkit-flex: 0 0 90%;
        -ms-flex: 0 0 90%;
            flex: 0 0 90%; }
  .layout-gt-lg-row > .flex-gt-lg-90, .md-css-only [layout="row"] > .md-css-only [flex-gt-lg="90"] {
    max-width: 90%;
    max-height: 100%; }
  .layout-gt-lg-column > .flex-gt-lg-90, .md-css-only [layout="column"] > .md-css-only [flex-gt-lg="90"] {
    max-height: 90%;
    max-width: 100%; }
  .flex-gt-lg-95, .md-css-only [flex-gt-lg="95"] {
    -webkit-flex: 0 0 95%;
        -ms-flex: 0 0 95%;
            flex: 0 0 95%; }
  .layout-gt-lg-row > .flex-gt-lg-95, .md-css-only [layout="row"] > .md-css-only [flex-gt-lg="95"] {
    max-width: 95%;
    max-height: 100%; }
  .layout-gt-lg-column > .flex-gt-lg-95, .md-css-only [layout="column"] > .md-css-only [flex-gt-lg="95"] {
    max-height: 95%;
    max-width: 100%; }
  .flex-gt-lg-100, .md-css-only [flex-gt-lg="100"] {
    -webkit-flex: 0 0 100%;
        -ms-flex: 0 0 100%;
            flex: 0 0 100%; }
  .layout-gt-lg-row > .flex-gt-lg-100, .md-css-only [layout="row"] > .md-css-only [flex-gt-lg="100"] {
    max-width: 100%;
    max-height: 100%; }
  .layout-gt-lg-column > .flex-gt-lg-100, .md-css-only [layout="column"] > .md-css-only [flex-gt-lg="100"] {
    max-height: 100%;
    max-width: 100%; }
  .flex-gt-lg-33, .flex-gt-lg-34 {
    -webkit-flex: 0 0 33%;
        -ms-flex: 0 0 33%;
            flex: 0 0 33%;
    max-width: 33%;
    max-height: 100%; }
  .flex-gt-lg-66, .flex-gt-lg-67 {
    -webkit-flex: 0 0 67%;
        -ms-flex: 0 0 67%;
            flex: 0 0 67%;
    max-width: 67%;
    max-height: 100%; }
  .layout-gt-lg-row > .flex-gt-lg-33, .layout-gt-lg-row > .flex-gt-lg-34 {
    max-width: 33%;
    max-height: 100%; }
  .layout-gt-lg-row > .flex-gt-lg-66, .layout-gt-lg-row > .flex-gt-lg-67 {
    max-width: 67%;
    max-height: 100%; }
  .layout-gt-lg-column > .flex-gt-lg-33, .layout-gt-lg-column > .flex-gt-lg-34 {
    max-height: 33%;
    max-width: 100%; }
  .layout-gt-lg-column > .flex-gt-lg-66, .layout-gt-lg-column > .flex-gt-lg-67 {
    max-height: 67%;
    max-width: 100%; } }
